@@ -34,6 +34,23 @@
 
 #include <arvbufferprivate.h>
 
+gboolean
+arv_buffer_payload_type_has_chunks (ArvBufferPayloadType payload_type)
+{
+	return (payload_type == ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA ||
+		payload_type == ARV_BUFFER_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA ||
+		payload_type == ARV_BUFFER_PAYLOAD_TYPE_IMAGE_EXTENDED_CHUNK);
+}
+
+gboolean
+arv_buffer_payload_type_has_aoi (ArvBufferPayloadType payload_type)
+{
+
+	return (payload_type == ARV_BUFFER_PAYLOAD_TYPE_IMAGE ||
+		payload_type == ARV_BUFFER_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA ||
+		payload_type == ARV_BUFFER_PAYLOAD_TYPE_IMAGE_EXTENDED_CHUNK);
+}
+
 /**
  * arv_buffer_new_full:
  * @size: payload size
@@ -145,6 +162,23 @@ typedef struct ARAVIS_PACKED_STRUCTURE {
 	guint32 size;
 } ArvChunkInfos;
 
+/**
+ * arv_buffer_has_chunks:
+ * @buffer: a #ArvBuffer
+ *
+ * Returns: %TRUE if @buffer has a payload type that contains chunk data.
+ *
+ * Since: 0.8.0
+ */
+
+gboolean
+arv_buffer_has_chunks (ArvBuffer *buffer)
+{
+	return ARV_IS_BUFFER (buffer) &&
+		buffer->priv->status == ARV_BUFFER_STATUS_SUCCESS &&
+		arv_buffer_payload_type_has_chunks (buffer->priv->payload_type);
+}
+
 /**
  * arv_buffer_get_chunk_data:
  * @buffer: a #ArvBuffer
@@ -168,13 +202,8 @@ arv_buffer_get_chunk_data (ArvBuffer *buffer, guint64 chunk_id, size_t *size)
 	if (size != NULL)
 		*size = 0;
 
-	g_return_val_if_fail (ARV_IS_BUFFER (buffer), NULL);
+	g_return_val_if_fail (arv_buffer_has_chunks (buffer), NULL);
 	g_return_val_if_fail (buffer->priv->data != NULL, NULL);
-	g_return_val_if_fail (buffer->priv->payload_type == ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA ||
-			      buffer->priv->payload_type == ARV_BUFFER_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA, NULL);
-
-	if (buffer->priv->status != ARV_BUFFER_STATUS_SUCCESS)
-		return NULL;
 
 	data = buffer->priv->data;
 	offset = buffer->priv->size - sizeof (ArvChunkInfos);
@@ -387,8 +416,7 @@ void
 arv_buffer_get_image_region (ArvBuffer *buffer, gint *x, gint *y, gint *width, gint *height)
 {
 	g_return_if_fail (ARV_IS_BUFFER (buffer));
-	g_return_if_fail (buffer->priv->payload_type == ARV_BUFFER_PAYLOAD_TYPE_IMAGE ||
-			  buffer->priv->payload_type == ARV_BUFFER_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA);
+	g_return_if_fail (arv_buffer_payload_type_has_aoi (buffer->priv->payload_type));
 
 	if (x != NULL)
 		*x = buffer->priv->x_offset;
@@ -415,8 +443,7 @@ gint
 arv_buffer_get_image_width (ArvBuffer *buffer)
 {
 	g_return_val_if_fail (ARV_IS_BUFFER (buffer), 0);
-	g_return_val_if_fail (buffer->priv->payload_type == ARV_BUFFER_PAYLOAD_TYPE_IMAGE ||
-			      buffer->priv->payload_type == ARV_BUFFER_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA, 0);
+	g_return_val_if_fail (arv_buffer_payload_type_has_aoi (buffer->priv->payload_type), 0);
 
 	return buffer->priv->width;
 }
@@ -436,8 +463,7 @@ gint
 arv_buffer_get_image_height (ArvBuffer *buffer)
 {
 	g_return_val_if_fail (ARV_IS_BUFFER (buffer), 0);
-	g_return_val_if_fail (buffer->priv->payload_type == ARV_BUFFER_PAYLOAD_TYPE_IMAGE ||
-			      buffer->priv->payload_type == ARV_BUFFER_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA, 0);
+	g_return_val_if_fail (arv_buffer_payload_type_has_aoi (buffer->priv->payload_type), 0);
 
 	return buffer->priv->height;
 }
@@ -457,8 +483,7 @@ gint
 arv_buffer_get_image_x (ArvBuffer *buffer)
 {
 	g_return_val_if_fail (ARV_IS_BUFFER (buffer), 0);
-	g_return_val_if_fail (buffer->priv->payload_type == ARV_BUFFER_PAYLOAD_TYPE_IMAGE ||
-			      buffer->priv->payload_type == ARV_BUFFER_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA, 0);
+	g_return_val_if_fail (arv_buffer_payload_type_has_aoi (buffer->priv->payload_type), 0);
 
 	return buffer->priv->x_offset;
 }
@@ -478,8 +503,7 @@ gint
 arv_buffer_get_image_y (ArvBuffer *buffer)
 {
 	g_return_val_if_fail (ARV_IS_BUFFER (buffer), 0);
-	g_return_val_if_fail (buffer->priv->payload_type == ARV_BUFFER_PAYLOAD_TYPE_IMAGE ||
-			      buffer->priv->payload_type == ARV_BUFFER_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA, 0);
+	g_return_val_if_fail (arv_buffer_payload_type_has_aoi (buffer->priv->payload_type), 0);
 
 	return buffer->priv->y_offset;
 }
@@ -499,8 +523,7 @@ ArvPixelFormat
 arv_buffer_get_image_pixel_format (ArvBuffer *buffer)
 {
 	g_return_val_if_fail (ARV_IS_BUFFER (buffer), 0);
-	g_return_val_if_fail (buffer->priv->payload_type == ARV_BUFFER_PAYLOAD_TYPE_IMAGE ||
-			      buffer->priv->payload_type == ARV_BUFFER_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA, 0);
+	g_return_val_if_fail (arv_buffer_payload_type_has_aoi (buffer->priv->payload_type), 0);
 
 	return buffer->priv->pixel_format;
 }
