@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2010 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -60,7 +60,7 @@ ArvDevice *	arv_camera_get_device		(ArvCamera *camera);
 
 ArvStream *	arv_camera_create_stream	(ArvCamera *camera, ArvStreamCallback callback, void *user_data);
 
-/* Device control */
+/* Device informations */
 
 const char *	arv_camera_get_vendor_name	(ArvCamera *camera);
 const char *	arv_camera_get_model_name	(ArvCamera *camera);
@@ -68,17 +68,23 @@ const char *	arv_camera_get_device_id	(ArvCamera *camera);
 
 /* Image format control */
 
-void 		arv_camera_get_sensor_size 	(ArvCamera *camera, gint *width, gint *height);
-void		arv_camera_set_region		(ArvCamera *camera, gint x, gint y, gint width, gint height);
-void		arv_camera_get_region		(ArvCamera *camera, gint *x, gint *y, gint *width, gint *height);
-void		arv_camera_get_x_offset_bounds	(ArvCamera *camera, gint *min, gint *max);
-void		arv_camera_get_y_offset_bounds	(ArvCamera *camera, gint *min, gint *max);
-void		arv_camera_get_width_bounds	(ArvCamera *camera, gint *min, gint *max);
-void		arv_camera_get_height_bounds	(ArvCamera *camera, gint *min, gint *max);
-void		arv_camera_set_binning		(ArvCamera *camera, gint dx, gint dy);
-void		arv_camera_get_binning		(ArvCamera *camera, gint *dx, gint *dy);
-void		arv_camera_get_x_binning_bounds	(ArvCamera *camera, gint *min, gint *max);
-void		arv_camera_get_y_binning_bounds	(ArvCamera *camera, gint *min, gint *max);
+void 		arv_camera_get_sensor_size 		(ArvCamera *camera, gint *width, gint *height);
+void		arv_camera_set_region			(ArvCamera *camera, gint x, gint y, gint width, gint height);
+void		arv_camera_get_region			(ArvCamera *camera, gint *x, gint *y, gint *width, gint *height);
+void		arv_camera_get_x_offset_bounds		(ArvCamera *camera, gint *min, gint *max);
+gint		arv_camera_get_x_offset_increment	(ArvCamera *camera);
+void		arv_camera_get_y_offset_bounds		(ArvCamera *camera, gint *min, gint *max);
+gint		arv_camera_get_y_offset_increment	(ArvCamera *camera);
+void		arv_camera_get_width_bounds		(ArvCamera *camera, gint *min, gint *max);
+gint		arv_camera_get_width_increment		(ArvCamera *camera);
+void		arv_camera_get_height_bounds		(ArvCamera *camera, gint *min, gint *max);
+gint		arv_camera_get_height_increment		(ArvCamera *camera);
+void		arv_camera_set_binning			(ArvCamera *camera, gint dx, gint dy);
+void		arv_camera_get_binning			(ArvCamera *camera, gint *dx, gint *dy);
+void		arv_camera_get_x_binning_bounds		(ArvCamera *camera, gint *min, gint *max);
+gint		arv_camera_get_x_binning_increment	(ArvCamera *camera);
+void		arv_camera_get_y_binning_bounds		(ArvCamera *camera, gint *min, gint *max);
+gint		arv_camera_get_y_binning_increment	(ArvCamera *camera);
 
 gboolean	arv_camera_is_binning_available (ArvCamera *camera);
 
@@ -98,11 +104,11 @@ void		arv_camera_abort_acquisition		(ArvCamera *camera);
 
 ArvBuffer *	arv_camera_acquisition			(ArvCamera *camera, guint64 timeout);
 
-void			arv_camera_set_acquisition_mode 	(ArvCamera *camera, ArvAcquisitionMode value);
-ArvAcquisitionMode 	arv_camera_get_acquisition_mode 	(ArvCamera *camera);
+void			arv_camera_set_acquisition_mode (ArvCamera *camera, ArvAcquisitionMode value);
+ArvAcquisitionMode 	arv_camera_get_acquisition_mode (ArvCamera *camera);
 
-void 		arv_camera_set_frame_count	(ArvCamera *camera, gint64 frame_count);
-gint64		arv_camera_get_frame_count	(ArvCamera *camera);
+void 		arv_camera_set_frame_count		(ArvCamera *camera, gint64 frame_count);
+gint64		arv_camera_get_frame_count		(ArvCamera *camera);
 void		arv_camera_get_frame_count_bounds	(ArvCamera *camera, gint64 *min, gint64 *max);
 
 gboolean 	arv_camera_is_frame_rate_available 	(ArvCamera *camera);
@@ -142,6 +148,33 @@ ArvAuto		arv_camera_get_gain_auto	(ArvCamera *camera);
 
 guint		arv_camera_get_payload		(ArvCamera *camera);
 
+/* Generic feature control */
+
+void 		arv_camera_execute_command 		(ArvCamera *camera, const char *feature);
+
+void		arv_camera_set_boolean			(ArvCamera *camera, const char *feature, gboolean value);
+gboolean	arv_camera_get_boolean			(ArvCamera *camera, const char *feature);
+
+void		arv_camera_set_string			(ArvCamera *camera, const char *feature, const char *value);
+const char *	arv_camera_get_string			(ArvCamera *camera, const char *feature);
+
+void		arv_camera_set_integer			(ArvCamera *camera, const char *feature, gint64 value);
+gint64		arv_camera_get_integer			(ArvCamera *camera, const char *feature);
+void 		arv_camera_get_integer_bounds 		(ArvCamera *camera, const char *feature, gint64 *min, gint64 *max);
+gint64		arv_camera_get_integer_increment	(ArvCamera *camera, const char *feature);
+
+void		arv_camera_set_float			(ArvCamera *camera, const char *feature, double value);
+double		arv_camera_get_float			(ArvCamera *camera, const char *feature);
+void 		arv_camera_get_float_bounds 		(ArvCamera *camera, const char *feature, double *min, double *max);
+
+gint64 *	arv_camera_get_available_enumerations			(ArvCamera *camera, const char *feature, guint *n_values);
+const char **	arv_camera_get_available_enumerations_as_strings	(ArvCamera *camera, const char *feature, guint *n_values);
+const char ** 	arv_camera_get_available_enumerations_as_display_names 	(ArvCamera *camera, const char *feature, guint *n_values);
+
+gboolean 	arv_camera_is_feature_available 	(ArvCamera *camera, const char *feature);
+
+ArvStatus 	arv_camera_get_status			(ArvCamera *camera, GError **error);
+
 /* GigEVision specific API */
 
 gboolean	arv_camera_is_gv_device			(ArvCamera *camera);
@@ -152,7 +185,7 @@ int 		arv_camera_gv_get_current_stream_channel(ArvCamera *camera);
 
 void		arv_camera_gv_set_packet_delay		(ArvCamera *camera, gint64 delay_ns);
 gint64 		arv_camera_gv_get_packet_delay 		(ArvCamera *camera);
-void 		arv_camera_gv_set_packet_size 		(ArvCamera *camera, guint packet_size);
+void 		arv_camera_gv_set_packet_size 		(ArvCamera *camera, gint packet_size);
 guint		arv_camera_gv_get_packet_size		(ArvCamera *camera);
 guint		arv_camera_gv_auto_packet_size		(ArvCamera *camera);
 
@@ -164,7 +197,7 @@ gboolean        arv_camera_is_uv_device                 	(ArvCamera *camera);
 gboolean        arv_camera_uv_is_bandwidth_control_available 	(ArvCamera *camera);
 void            arv_camera_uv_set_bandwidth             	(ArvCamera *camera, guint bandwidth);
 guint           arv_camera_uv_get_bandwidth             	(ArvCamera *camera);
-void            arv_camera_uv_get_bandwidth_bounds      	(ArvCamera *camera, guint* min, guint* max);
+void            arv_camera_uv_get_bandwidth_bounds      	(ArvCamera *camera, guint *min, guint *max);
 
 /* Chunk data */
 
