@@ -50,6 +50,7 @@
 #include <arvgcinteger.h>
 #include <arvgcfloat.h>
 #include <arvgcstring.h>
+#include <arvgcboolean.h>
 #include <arvdebug.h>
 
 enum {
@@ -68,19 +69,57 @@ struct _ArvChunkParserPrivate {
 	ArvGc *genicam;
 };
 
+/**
+ * arv_chunk_parser_get_boolean_value:
+ * @parser: a #ArvChunkParser
+ * @buffer: a #ArvBuffer with a #ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA payload
+ * @chunk: chunk data name
+ * @error: a #GError placeholder
+ *
+ * Returns: the boolean chunk data value.
+ */
+
+gboolean
+arv_chunk_parser_get_boolean_value (ArvChunkParser *parser, ArvBuffer *buffer, const char *chunk, GError **error)
+{
+	ArvGcNode *node;
+	gboolean value = FALSE;
+
+	g_return_val_if_fail (ARV_IS_CHUNK_PARSER (parser), 0.0);
+	g_return_val_if_fail (ARV_IS_BUFFER (buffer), 0.0);
+
+	node = arv_gc_get_node (parser->priv->genicam, chunk);
+	arv_gc_set_buffer (parser->priv->genicam, buffer);
+
+	if (ARV_IS_GC_BOOLEAN (node)) {
+		GError *local_error = NULL;
+
+		value = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), &local_error);
+
+		if (local_error != NULL) {
+			arv_warning_chunk ("%s", local_error->message);
+			g_propagate_error (error, local_error);
+		}
+	} else {
+		g_set_error (error, ARV_CHUNK_PARSER_ERROR, ARV_CHUNK_PARSER_ERROR_INVALID_FEATURE_TYPE,
+			     "Node '%s' is not a boolean", chunk);
+	}
+
+	return value;
+}
+
 /**
  * arv_chunk_parser_get_string_value:
  * @parser: a #ArvChunkParser
  * @buffer: a #ArvBuffer with a #ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA payload
  * @chunk: chunk data name
+ * @error: a #GError placeholder
  *
- * Gets the value of chunk data as a string.
- *
- * Returns: the chunk data string value.
+ * Returns: the string chunk data value.
  */
 
 const char *
-arv_chunk_parser_get_string_value (ArvChunkParser *parser, ArvBuffer *buffer, const char *chunk)
+arv_chunk_parser_get_string_value (ArvChunkParser *parser, ArvBuffer *buffer, const char *chunk, GError **error)
 {
 	ArvGcNode *node;
 	const char *string = NULL;
@@ -92,16 +131,18 @@ arv_chunk_parser_get_string_value (ArvChunkParser *parser, ArvBuffer *buffer, co
 	arv_gc_set_buffer (parser->priv->genicam, buffer);
 
 	if (ARV_IS_GC_STRING (node)) {
-		GError *error = NULL;
+		GError *local_error = NULL;
 
-		string = arv_gc_string_get_value (ARV_GC_STRING (node), NULL);
+		string = arv_gc_string_get_value (ARV_GC_STRING (node), &local_error);
 
-		if (error != NULL) {
-			arv_warning_chunk ("%s", error->message);
-			g_clear_error (&error);
+		if (local_error != NULL) {
+			arv_warning_chunk ("%s", local_error->message);
+			g_propagate_error (error, local_error);
 		}
-	} else
-		arv_warning_device ("[ArvChunkParser::get_string_value] Node '%s' is not a string", chunk);
+	} else {
+		g_set_error (error, ARV_CHUNK_PARSER_ERROR, ARV_CHUNK_PARSER_ERROR_INVALID_FEATURE_TYPE,
+			     "Node '%s' is not a string", chunk);
+	}
 
 	return string;
 }
@@ -111,14 +152,13 @@ arv_chunk_parser_get_string_value (ArvChunkParser *parser, ArvBuffer *buffer, co
  * @parser: a #ArvChunkParser
  * @buffer: a #ArvBuffer with a #ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA payload
  * @chunk: chunk data name
+ * @error: a #GError placeholder
  *
- * Gets the value of chunk data as an integer.
- *
- * Returns: the chunk data integer value.
+ * Returns: the integer chunk data integer.
  */
 
 gint64
-arv_chunk_parser_get_integer_value (ArvChunkParser *parser, ArvBuffer *buffer, const char *chunk)
+arv_chunk_parser_get_integer_value (ArvChunkParser *parser, ArvBuffer *buffer, const char *chunk, GError **error)
 {
 	ArvGcNode *node;
 	gint64 value = 0;
@@ -130,16 +170,18 @@ arv_chunk_parser_get_integer_value (ArvChunkParser *parser, ArvBuffer *buffer, c
 	arv_gc_set_buffer (parser->priv->genicam, buffer);
 
 	if (ARV_IS_GC_INTEGER (node)) {
-		GError *error = NULL;
+		GError *local_error = NULL;
 
-		value = arv_gc_integer_get_value (ARV_GC_INTEGER (node), &error);
+		value = arv_gc_integer_get_value (ARV_GC_INTEGER (node), &local_error);
 
-		if (error != NULL) {
-			arv_warning_chunk ("%s", error->message);
-			g_clear_error (&error);
+		if (local_error != NULL) {
+			arv_warning_chunk ("%s", local_error->message);
+			g_propagate_error (error, local_error);
 		}
-	} else
-		arv_warning_device ("[ArvChunkParser::get_integer_value] Node '%s' is not an integer", chunk);
+	} else {
+		g_set_error (error, ARV_CHUNK_PARSER_ERROR, ARV_CHUNK_PARSER_ERROR_INVALID_FEATURE_TYPE,
+			     "Node '%s' is not an integer", chunk);
+	}
 
 	return value;
 }
@@ -149,14 +191,13 @@ arv_chunk_parser_get_integer_value (ArvChunkParser *parser, ArvBuffer *buffer, c
  * @parser: a #ArvChunkParser
  * @buffer: a #ArvBuffer with a #ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA payload
  * @chunk: chunk data name
+ * @error: a #GError placeholder
  *
- * Gets the value of chunk data as a float.
- *
- * Returns: the chunk data float value.
+ * Returns: the float chunk data value.
  */
 
 double
-arv_chunk_parser_get_float_value (ArvChunkParser *parser, ArvBuffer *buffer, const char *chunk)
+arv_chunk_parser_get_float_value (ArvChunkParser *parser, ArvBuffer *buffer, const char *chunk, GError **error)
 {
 	ArvGcNode *node;
 	double value = 0.0;
@@ -168,16 +209,18 @@ arv_chunk_parser_get_float_value (ArvChunkParser *parser, ArvBuffer *buffer, con
 	arv_gc_set_buffer (parser->priv->genicam, buffer);
 
 	if (ARV_IS_GC_FLOAT (node)) {
-		GError *error = NULL;
+		GError *local_error = NULL;
 
-		value = arv_gc_float_get_value (ARV_GC_FLOAT (node), NULL);
+		value = arv_gc_float_get_value (ARV_GC_FLOAT (node), &local_error);
 
-		if (error != NULL) {
-			arv_warning_chunk ("%s", error->message);
-			g_clear_error (&error);
+		if (local_error != NULL) {
+			arv_warning_chunk ("%s", local_error->message);
+			g_propagate_error (error, local_error);
 		}
-	} else
-		arv_warning_chunk ("[ArvChunkParser::get_float_value] Node '%s' is not a float", chunk);
+	} else {
+		g_set_error (error, ARV_CHUNK_PARSER_ERROR, ARV_CHUNK_PARSER_ERROR_INVALID_FEATURE_TYPE,
+			     "Node '%s' is not a float", chunk);
+	}
 
 	return value;
 }
