@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2014 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,6 +23,10 @@
 #ifndef ARV_DEVICE_PRIVATE_H
 #define ARV_DEVICE_PRIVATE_H
 
+#if !defined (ARV_H_INSIDE) && !defined (ARAVIS_COMPILATION)
+#error "Only <arv.h> can be included directly."
+#endif
+
 #include <arvdevice.h>
 
 G_BEGIN_DECLS
@@ -31,6 +35,11 @@ G_BEGIN_DECLS
 
 GQuark 		arv_device_error_quark 		(void);
 
+typedef enum {
+	ARV_DEVICE_ERROR_WRONG_FEATURE,
+	ARV_DEVICE_ERROR_FEATURE_NOT_FOUND
+} ArvDeviceError;
+
 void 		arv_device_emit_control_lost_signal 	(ArvDevice *device);
 
 G_END_DECLS
