@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2016 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -30,14 +30,9 @@
 #include <arvgc.h>
 #include <arvdebug.h>
 
-static GObjectClass *parent_class = NULL;
-
 struct _ArvFakeDevicePrivate {
 	ArvFakeCamera *camera;
 	ArvGc *genicam;
-
-	const char *genicam_xml;
-	size_t genicam_xml_size;
 };
 
 /* ArvFakeDevice implemenation */
@@ -60,9 +55,7 @@ arv_fake_device_get_genicam_xml (ArvDevice *device, size_t *size)
 {
 	ArvFakeDevice *fake_device = ARV_FAKE_DEVICE (device);
 
-	*size = fake_device->priv->genicam_xml_size;
-
-	return fake_device->priv->genicam_xml;
+	return arv_fake_camera_get_genicam_xml (fake_device->priv->camera, size);
 }
 
 static ArvGc *
@@ -116,25 +109,28 @@ ArvDevice *
 arv_fake_device_new (const char *serial_number)
 {
 	ArvFakeDevice *fake_device;
+	ArvFakeCamera *fake_camera;
+	const char *genicam_xml;
+	gsize genicam_xml_size;
 
 	g_return_val_if_fail (serial_number != NULL, NULL);
 
+	fake_camera = arv_fake_camera_new_full (serial_number, NULL);
+	genicam_xml = arv_fake_camera_get_genicam_xml (fake_camera, &genicam_xml_size);
+
 	fake_device = g_object_new (ARV_TYPE_FAKE_DEVICE, NULL);
-
-	fake_device->priv->camera = arv_fake_camera_new (serial_number);
-
-	fake_device->priv->genicam_xml = arv_get_fake_camera_genicam_xml (&fake_device->priv->genicam_xml_size);
-	fake_device->priv->genicam = arv_gc_new (ARV_DEVICE (fake_device),
-						 fake_device->priv->genicam_xml,
-						 fake_device->priv->genicam_xml_size);
+	fake_device->priv->camera = fake_camera;
+	fake_device->priv->genicam = arv_gc_new (ARV_DEVICE (fake_device), genicam_xml, genicam_xml_size);
 
 	return ARV_DEVICE (fake_device);
 }
 
+G_DEFINE_TYPE_WITH_CODE (ArvFakeDevice, arv_fake_device, ARV_TYPE_DEVICE, G_ADD_PRIVATE (ArvFakeDevice))
+
 static void
 arv_fake_device_init (ArvFakeDevice *fake_device)
 {
-	fake_device->priv = G_TYPE_INSTANCE_GET_PRIVATE (fake_device, ARV_TYPE_FAKE_DEVICE, ArvFakeDevicePrivate);
+	fake_device->priv = arv_fake_device_get_instance_private (fake_device);
 }
 
 static void
@@ -145,7 +141,7 @@ arv_fake_device_finalize (GObject *object)
 	g_object_unref (fake_device->priv->genicam);
 	g_object_unref (fake_device->priv->camera);
 
-	parent_class->finalize (object);
+	G_OBJECT_CLASS (arv_fake_device_parent_class)->finalize (object);
 }
 
 static void
@@ -154,12 +150,6 @@ arv_fake_device_class_init (ArvFakeDeviceClass *fake_device_class)
 	GObjectClass *object_class = G_OBJECT_CLASS (fake_device_class);
 	ArvDeviceClass *device_class = ARV_DEVICE_CLASS (fake_device_class);
 
-#if !GLIB_CHECK_VERSION(2,38,0)
-	g_type_class_add_private (fake_device_class, sizeof (ArvFakeDevicePrivate));
-#endif
-
-	parent_class = g_type_class_peek_parent (fake_device_class);
-
 	object_class->finalize = arv_fake_device_finalize;
 
 	device_class->create_stream = arv_fake_device_create_stream;
@@ -170,9 +160,3 @@ arv_fake_device_class_init (ArvFakeDeviceClass *fake_device_class)
 	device_class->read_register = arv_fake_device_read_register;
 	device_class->write_register = arv_fake_device_write_register;
 }
-
-#if !GLIB_CHECK_VERSION(2,38,0)
-G_DEFINE_TYPE (ArvFakeDevice, arv_fake_device, ARV_TYPE_DEVICE)
-#else
-G_DEFINE_TYPE_WITH_CODE (ArvFakeDevice, arv_fake_device, ARV_TYPE_DEVICE, G_ADD_PRIVATE (ArvFakeDevice))
-#endif
