@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2010 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -32,16 +32,15 @@
 #include <arvdebug.h>
 #include <arvmisc.h>
 
-#define ARV_FAKE_DEVICE_ID "Fake_1"
-#define ARV_FAKE_PHYSICAL_ID "Fake_1"
-#define ARV_FAKE_ADDRESS "0.0.0.0"
+#define ARV_FAKE_DEVICE_ID 	"Fake_1"
+#define ARV_FAKE_PHYSICAL_ID 	"Fake_1"
+#define ARV_FAKE_ADDRESS 	"0.0.0.0"
+#define ARV_FAKE_VENDOR 	"Aravis"
+#define ARV_FAKE_MODEL 		"Fake"
+#define ARV_FAKE_SERIAL		"1"
 
 static GObjectClass *parent_class = NULL;
 
-struct _ArvFakeInterfacePrivate {
-	GHashTable *devices;
-};
-
 static void
 arv_fake_interface_update_device_list (ArvInterface *interface, GArray *device_ids)
 {
@@ -54,6 +53,9 @@ arv_fake_interface_update_device_list (ArvInterface *interface, GArray *device_i
 	ids->device = g_strdup (ARV_FAKE_DEVICE_ID);
 	ids->physical = g_strdup (ARV_FAKE_PHYSICAL_ID);
 	ids->address = g_strdup (ARV_FAKE_ADDRESS);
+	ids->vendor = g_strdup (ARV_FAKE_VENDOR);
+	ids->model = g_strdup (ARV_FAKE_MODEL);
+	ids->serial_nbr = g_strdup (ARV_FAKE_SERIAL);
 
 	g_array_append_val (device_ids, ids);
 }
@@ -61,16 +63,15 @@ arv_fake_interface_update_device_list (ArvInterface *interface, GArray *device_i
 static ArvDevice *
 arv_fake_interface_open_device (ArvInterface *interface, const char *device_id)
 {
-	if (g_strcmp0 (device_id, ARV_FAKE_DEVICE_ID) == 0)
-		return arv_fake_device_new ("1");
-	if (g_strcmp0 (device_id, ARV_FAKE_PHYSICAL_ID) == 0)
+	if (g_strcmp0 (device_id, ARV_FAKE_DEVICE_ID) == 0 ||
+	    g_strcmp0 (device_id, ARV_FAKE_PHYSICAL_ID) == 0)
 		return arv_fake_device_new ("1");
 
 	return NULL;
 }
 
 static ArvInterface *fake_interface = NULL;
-ARV_DEFINE_STATIC_MUTEX (fake_interface_mutex);
+static GMutex fake_interface_mutex;
 
 /**
  * arv_fake_interface_get_instance:
@@ -83,12 +84,12 @@ ARV_DEFINE_STATIC_MUTEX (fake_interface_mutex);
 ArvInterface *
 arv_fake_interface_get_instance (void)
 {
-	arv_g_mutex_lock (&fake_interface_mutex);
+	g_mutex_lock (&fake_interface_mutex);
 
 	if (fake_interface == NULL)
 		fake_interface = g_object_new (ARV_TYPE_FAKE_INTERFACE, NULL);
 
-	arv_g_mutex_unlock (&fake_interface_mutex);
+	g_mutex_unlock (&fake_interface_mutex);
 
 	return ARV_INTERFACE (fake_interface);
 }
@@ -96,34 +97,24 @@ arv_fake_interface_get_instance (void)
 void
 arv_fake_interface_destroy_instance (void)
 {
-	arv_g_mutex_lock (&fake_interface_mutex);
+	g_mutex_lock (&fake_interface_mutex);
 
 	if (fake_interface != NULL) {
 		g_object_unref (fake_interface);
 		fake_interface = NULL;
 	}
 
-	arv_g_mutex_unlock (&fake_interface_mutex);
+	g_mutex_unlock (&fake_interface_mutex);
 }
 
 static void
 arv_fake_interface_init (ArvFakeInterface *fake_interface)
 {
-	fake_interface->priv = G_TYPE_INSTANCE_GET_PRIVATE (fake_interface, ARV_TYPE_FAKE_INTERFACE, ArvFakeInterfacePrivate);
-
-	fake_interface->priv->devices = NULL;
 }
 
 static void
 arv_fake_interface_finalize (GObject *object)
 {
-	ArvFakeInterface *fake_interface = ARV_FAKE_INTERFACE (object);
-
-	if (fake_interface->priv->devices != NULL) {
-		g_hash_table_unref (fake_interface->priv->devices);
-		fake_interface->priv->devices = NULL;
-	}
-
 	parent_class->finalize (object);
 }
 
@@ -133,8 +124,6 @@ arv_fake_interface_class_init (ArvFakeInterfaceClass *fake_interface_class)
 	GObjectClass *object_class = G_OBJECT_CLASS (fake_interface_class);
 	ArvInterfaceClass *interface_class = ARV_INTERFACE_CLASS (fake_interface_class);
 
-	g_type_class_add_private (fake_interface_class, sizeof (ArvFakeInterfacePrivate));
-
 	parent_class = g_type_class_peek_parent (fake_interface_class);
 
 	object_class->finalize = arv_fake_interface_finalize;
