@@ -43,12 +43,18 @@
 #include <arvgcintegernode.h>
 #include <arvgcfloatnode.h>
 #include <arvgcregisternode.h>
+#include <arvgcintregnode.h>
+#include <arvgcmaskedintregnode.h>
+#include <arvgcfloatregnode.h>
+#include <arvgcstringregnode.h>
+#include <arvgcstructregnode.h>
 #include <arvgcstructentrynode.h>
 #include <arvgccommand.h>
 #include <arvgcinteger.h>
 #include <arvgcfloat.h>
 #include <arvgcboolean.h>
-#include <arvgcswissknife.h>
+#include <arvgcswissknifenode.h>
+#include <arvgcintswissknifenode.h>
 #include <arvgcconverternode.h>
 #include <arvgcintconverternode.h>
 #include <arvgcport.h>
@@ -99,15 +105,15 @@ arv_gc_create_element (ArvDomDocument *document, const char *tag_name)
 	else if (strcmp (tag_name, "Register") == 0)
 		node = arv_gc_register_node_new ();
 	else if (strcmp (tag_name, "IntReg") == 0)
-		node = arv_gc_register_node_new_integer ();
+		node = arv_gc_int_reg_node_new ();
 	else if (strcmp (tag_name, "MaskedIntReg") == 0)
-		node = arv_gc_register_node_new_masked_integer ();
+		node = arv_gc_masked_int_reg_node_new ();
 	else if (strcmp (tag_name, "FloatReg") == 0)
-		node = arv_gc_register_node_new_float ();
+		node = arv_gc_float_reg_node_new ();
 	else if (strcmp (tag_name, "StringReg") == 0)
-		node = arv_gc_register_node_new_string ();
+		node = arv_gc_string_reg_node_new ();
 	else if (strcmp (tag_name, "StructReg") == 0)
-		node = arv_gc_register_node_new_struct_register ();
+		node = arv_gc_struct_reg_node_new ();
 	else if (strcmp (tag_name, "StructEntry") == 0)
 		node = arv_gc_struct_entry_node_new ();
 	else if (strcmp (tag_name, "Integer") == 0)
@@ -121,9 +127,9 @@ arv_gc_create_element (ArvDomDocument *document, const char *tag_name)
 	else if (strcmp (tag_name, "EnumEntry") == 0)
 		node = arv_gc_enum_entry_new ();
 	else if (strcmp (tag_name, "SwissKnife") == 0)
-		node = arv_gc_swiss_knife_new ();
+		node = arv_gc_swiss_knife_node_new ();
 	else if (strcmp (tag_name, "IntSwissKnife") == 0)
-		node = arv_gc_swiss_knife_new_integer ();
+		node = arv_gc_int_swiss_knife_node_new ();
 	else if (strcmp (tag_name, "Port") == 0)
 		node = arv_gc_port_new ();
 	else if (strcmp (tag_name, "pIndex") == 0)
@@ -174,6 +180,8 @@ arv_gc_create_element (ArvDomDocument *document, const char *tag_name)
 		node = arv_gc_property_node_new_p_is_available ();
 	else if (strcmp (tag_name, "pIsLocked") == 0)
 		node = arv_gc_property_node_new_p_is_locked ();
+	else if (strcmp (tag_name, "pSelected") == 0)
+		node = arv_gc_property_node_new_p_selected ();
 	else if (strcmp (tag_name, "Length") == 0)
 		node = arv_gc_property_node_new_length ();
 	else if (strcmp (tag_name, "pLength") == 0)
@@ -203,6 +211,8 @@ arv_gc_create_element (ArvDomDocument *document, const char *tag_name)
 
 	else if (strcmp (tag_name, "AccessMode") == 0)
 		node = arv_gc_property_node_new_access_mode ();
+	else if (strcmp (tag_name, "ImposedAccessMode") == 0)
+		node = arv_gc_property_node_new_imposed_access_mode ();
 	else if (strcmp (tag_name, "Cachable") == 0)
 		node = arv_gc_property_node_new_cachable ();
 	else if (strcmp (tag_name, "PollingTime") == 0)
@@ -227,6 +237,8 @@ arv_gc_create_element (ArvDomDocument *document, const char *tag_name)
 
 	else if (strcmp (tag_name, "ChunkID") == 0)
 		node = arv_gc_property_node_new_chunk_id ();
+	else if (strcmp (tag_name, "EventID") == 0)
+		node = arv_gc_property_node_new_event_id ();
 
 	else if (strcmp (tag_name, "Group") == 0)
 		node = arv_gc_group_node_new ();
