@@ -42,7 +42,13 @@ typedef enum {
 	ARV_GC_ERROR_INVALID_PVALUE,
 	ARV_GC_ERROR_EMPTY_ENUMERATION,
 	ARV_GC_ERROR_OUT_OF_RANGE,
-	ARV_GC_ERROR_NODE_NOT_FOUND
+	ARV_GC_ERROR_NO_DEVICE_SET,
+	ARV_GC_ERROR_NO_EVENT_IMPLEMENTATION,
+	ARV_GC_ERROR_NODE_NOT_FOUND,
+	ARV_GC_ERROR_INVALID_LENGTH,
+	ARV_GC_ERROR_READ_ONLY,
+	ARV_GC_ERROR_SET_FROM_STRING_UNDEFINED,
+	ARV_GC_ERROR_GET_AS_STRING_UNDEFINED
 } ArvGcError;
 
 /**
