@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2012 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,7 +27,6 @@
 #error "Only <arv.h> can be included directly."
 #endif
 
-#include <arvtypes.h>
 #include <arvgcfeaturenode.h>
 #include <arvgcpropertynode.h>
 
@@ -40,21 +39,13 @@ G_BEGIN_DECLS
 #define ARV_IS_GC_CONVERTER_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), ARV_TYPE_GC_CONVERTER))
 #define ARV_GC_CONVERTER_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS((obj), ARV_TYPE_GC_CONVERTER, ArvGcConverterClass))
 
+typedef struct _ArvGcConverterPrivate ArvGcConverterPrivate;
 typedef struct _ArvGcConverterClass ArvGcConverterClass;
 
 struct _ArvGcConverter {
 	ArvGcFeatureNode	node;
 
-	GType value_type;
-	GSList *variables;	/* ArvGcVariableNode list */
-
-	ArvGcPropertyNode *value;
-	ArvGcPropertyNode *formula_to_node;
-	ArvGcPropertyNode *formula_from_node;
-	ArvGcPropertyNode *unit;
-
-	ArvEvaluator *formula_to;
-	ArvEvaluator *formula_from;
+	ArvGcConverterPrivate *priv;
 };
 
 struct _ArvGcConverterClass {
@@ -62,8 +53,6 @@ struct _ArvGcConverterClass {
 };
 
 GType 		arv_gc_converter_get_type 	(void);
-ArvGcNode * 	arv_gc_converter_new 		(void);
-ArvGcNode * 	arv_gc_converter_new_integer 	(void);
 
 G_END_DECLS
 
