@@ -28,6 +28,7 @@
 #include <arvgcenumeration.h>
 #include <arvgcenumentry.h>
 #include <arvgcinteger.h>
+#include <arvgcselector.h>
 #include <arvgcstring.h>
 #include <arvgcfeaturenodeprivate.h>
 #include <arvgc.h>
@@ -64,6 +65,9 @@ arv_gc_enumeration_post_new_child (ArvDomNode *self, ArvDomNode *child)
 			case ARV_GC_PROPERTY_NODE_TYPE_P_VALUE:
 				node->value = property_node;
 				break;
+			case ARV_GC_PROPERTY_NODE_TYPE_P_SELECTED:
+				node->selecteds = g_slist_prepend (node->selecteds, property_node);
+				break;
 			default:
 				ARV_DOM_NODE_CLASS (parent_class)->post_new_child (self, child);
 				break;
@@ -78,42 +82,6 @@ arv_gc_enumeration_pre_remove_child (ArvDomNode *self, ArvDomNode *child)
 	g_assert_not_reached ();
 }
 
-/* ArvGcFeatureNode implementation */
-
-static void
-arv_gc_enumeration_set_value_from_string (ArvGcFeatureNode *node, const char *string, GError **error)
-{
-	GError *local_error = NULL;
-
-	arv_gc_enumeration_set_string_value (ARV_GC_ENUMERATION (node), string, &local_error);
-
-	if (local_error != NULL)
-		g_propagate_error (error, local_error);
-}
-
-static const char *
-arv_gc_enumeration_get_value_as_string (ArvGcFeatureNode *node, GError **error)
-{
-	const char *string;
-	GError *local_error = NULL;
-
-	string = arv_gc_enumeration_get_string_value (ARV_GC_ENUMERATION (node), &local_error);
-
-	if (local_error != NULL) {
-		g_propagate_error (error, local_error);
-		return NULL;
-	}
-
-	return string;
-}
-
-GType
-arv_gc_enumeration_get_value_type (ArvGcFeatureNode *node)
-{
-	return G_TYPE_INT64;
-}
-
-
 /* ArvGcEnumeration implementation */
 
 const char *
@@ -516,8 +484,9 @@ arv_gc_enumeration_finalize (GObject *object)
 {
 	ArvGcEnumeration *enumeration = ARV_GC_ENUMERATION (object);
 
-	g_slist_free (enumeration->entries);
-	enumeration->entries = NULL;
+	g_clear_pointer (&enumeration->entries, g_slist_free);
+	g_clear_pointer (&enumeration->selecteds, g_slist_free);
+	g_clear_pointer (&enumeration->selected_features, g_slist_free);
 
 	parent_class->finalize (object);
 }
@@ -527,7 +496,6 @@ arv_gc_enumeration_class_init (ArvGcEnumerationClass *this_class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (this_class);
 	ArvDomNodeClass *dom_node_class = ARV_DOM_NODE_CLASS (this_class);
-	ArvGcFeatureNodeClass *gc_feature_node_class = ARV_GC_FEATURE_NODE_CLASS (this_class);
 
 	parent_class = g_type_class_peek_parent (this_class);
 
@@ -537,9 +505,6 @@ arv_gc_enumeration_class_init (ArvGcEnumerationClass *this_class)
 	dom_node_class->can_append_child = arv_gc_enumeration_can_append_child;
 	dom_node_class->post_new_child = arv_gc_enumeration_post_new_child;
 	dom_node_class->pre_remove_child = arv_gc_enumeration_pre_remove_child;
-	gc_feature_node_class->set_value_from_string = arv_gc_enumeration_set_value_from_string;
-	gc_feature_node_class->get_value_as_string = arv_gc_enumeration_get_value_as_string;
-	gc_feature_node_class->get_value_type = arv_gc_enumeration_get_value_type;
 }
 
 /* ArvGcInteger interface implementation */
@@ -611,6 +576,29 @@ arv_gc_enumeration_string_interface_init (ArvGcStringInterface *interface)
 	interface->get_max_length = arv_gc_enumeration_get_max_string_length;
 }
 
+const GSList *
+arv_gc_enumeration_get_selected_features (ArvGcSelector *selector)
+{
+	ArvGcEnumeration *enumeration = ARV_GC_ENUMERATION (selector);
+	GSList *iter;
+
+	g_clear_pointer (&enumeration->selected_features, g_slist_free);
+	for (iter = enumeration->selecteds; iter != NULL; iter = iter->next) {
+		ArvGcFeatureNode *feature_node = ARV_GC_FEATURE_NODE (arv_gc_property_node_get_linked_node (iter->data));
+		if (ARV_IS_GC_FEATURE_NODE (feature_node))
+		    enumeration->selected_features = g_slist_prepend (enumeration->selected_features, feature_node);
+	}
+
+	return enumeration->selected_features;
+}
+
+static void
+arv_gc_enumeration_selector_interface_init (ArvGcSelectorInterface *interface)
+{
+	interface->get_selected_features = arv_gc_enumeration_get_selected_features;
+}
+
 G_DEFINE_TYPE_WITH_CODE (ArvGcEnumeration, arv_gc_enumeration, ARV_TYPE_GC_FEATURE_NODE,
 			 G_IMPLEMENT_INTERFACE (ARV_TYPE_GC_INTEGER, arv_gc_enumeration_integer_interface_init)
-			 G_IMPLEMENT_INTERFACE (ARV_TYPE_GC_STRING, arv_gc_enumeration_string_interface_init))
+			 G_IMPLEMENT_INTERFACE (ARV_TYPE_GC_STRING, arv_gc_enumeration_string_interface_init)
+			 G_IMPLEMENT_INTERFACE (ARV_TYPE_GC_SELECTOR, arv_gc_enumeration_selector_interface_init))
