@@ -29,6 +29,7 @@
 
 #include <arvtypes.h>
 #include <arvgcnode.h>
+#include <arvgcenums.h>
 
 G_BEGIN_DECLS
 
@@ -50,11 +51,6 @@ struct _ArvGcFeatureNode {
 
 struct _ArvGcFeatureNodeClass {
 	ArvGcNodeClass parent_class;
-
-	GType		(*get_value_type)		(ArvGcFeatureNode *gc_feature_node);
-
-	void		(*set_value_from_string)	(ArvGcFeatureNode *gc_feature_node, const char *string, GError **error);
-	const char *	(*get_value_as_string)		(ArvGcFeatureNode *gc_feature_node, GError **error);
 };
 
 GType 			arv_gc_feature_node_get_type 			(void);
@@ -68,12 +64,11 @@ const char *		arv_gc_feature_node_get_display_name		(ArvGcFeatureNode *gc_featur
 gboolean		arv_gc_feature_node_is_available		(ArvGcFeatureNode *gc_feature_node, GError **error);
 gboolean		arv_gc_feature_node_is_implemented		(ArvGcFeatureNode *gc_feature_node, GError **error);
 gboolean		arv_gc_feature_node_is_locked			(ArvGcFeatureNode *gc_feature_node, GError **error);
+
 void			arv_gc_feature_node_set_value_from_string	(ArvGcFeatureNode *gc_feature_node, const char *string,
 									 GError **error);
 const char *		arv_gc_feature_node_get_value_as_string		(ArvGcFeatureNode *gc_feature_node, GError **error);
 
-GType 			arv_gc_feature_node_get_value_type 		(ArvGcFeatureNode *gc_feature_node);
-
 G_END_DECLS
 
 #endif
