@@ -27,6 +27,7 @@
 
 #include <arvgcfloatnode.h>
 #include <arvgcfloat.h>
+#include <arvgcinteger.h>
 #include <arvgcvalueindexednode.h>
 #include <arvgcfeaturenodeprivate.h>
 #include <arvgc.h>
@@ -127,40 +128,6 @@ _get_value_node (ArvGcFloatNode *gc_float_node, GError **error)
 	return NULL;
 }
 
-static GType
-arv_gc_float_node_get_value_type (ArvGcFeatureNode *node)
-{
-	return G_TYPE_DOUBLE;
-}
-
-
-static void
-arv_gc_float_node_set_value_from_string (ArvGcFeatureNode *node, const char *string, GError **error)
-{
-	arv_gc_float_set_value (ARV_GC_FLOAT (node), g_ascii_strtod (string, NULL), error);
-}
-
-static const char *
-arv_gc_float_node_get_value_as_string (ArvGcFeatureNode *node, GError **error)
-{
-	ArvGcFloatNode *float_node = ARV_GC_FLOAT_NODE (node);
-	ArvGcPropertyNode *value_node;
-	GError *local_error = NULL;
-	const char *string;
-
-	value_node = _get_value_node (float_node, error);
-	if (value_node == NULL)
-		return NULL;
-
-	string = arv_gc_property_node_get_string (ARV_GC_PROPERTY_NODE (value_node), &local_error);
-	if (local_error != NULL) {
-		g_propagate_error (error, local_error);
-		return NULL;
-	}
-
-	return string;
-}
-
 /* ArvGcFloatNode implementation */
 
 ArvGcNode *
@@ -193,7 +160,6 @@ arv_gc_float_node_class_init (ArvGcFloatNodeClass *this_class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (this_class);
 	ArvDomNodeClass *dom_node_class = ARV_DOM_NODE_CLASS (this_class);
-	ArvGcFeatureNodeClass *gc_feature_node_class = ARV_GC_FEATURE_NODE_CLASS (this_class);
 
 	parent_class = g_type_class_peek_parent (this_class);
 
@@ -201,9 +167,6 @@ arv_gc_float_node_class_init (ArvGcFloatNodeClass *this_class)
 	dom_node_class->get_node_name = arv_gc_float_node_get_node_name;
 	dom_node_class->post_new_child = arv_gc_float_node_post_new_child;
 	dom_node_class->pre_remove_child = arv_gc_float_node_pre_remove_child;
-	gc_feature_node_class->get_value_type = arv_gc_float_node_get_value_type;
-	gc_feature_node_class->set_value_from_string = arv_gc_float_node_set_value_from_string;
-	gc_feature_node_class->get_value_as_string = arv_gc_float_node_get_value_as_string;
 }
 
 /* ArvGcFloat interface implementation */
@@ -253,8 +216,25 @@ arv_gc_float_node_get_min (ArvGcFloat *gc_float, GError **error)
 	GError *local_error = NULL;
 	double value;
 
-	if (gc_float_node->minimum == NULL)
+	if (gc_float_node->minimum == NULL) {
+		ArvGcPropertyNode *value_node;
+
+		value_node = _get_value_node (gc_float_node, &local_error);
+		if (local_error != NULL) {
+			g_propagate_error (error, local_error);
+			return -G_MAXDOUBLE;
+		}
+
+		if (ARV_IS_GC_PROPERTY_NODE (value_node)) {
+			ArvGcNode *linked_node = arv_gc_property_node_get_linked_node (value_node);
+
+			if (ARV_IS_GC_INTEGER (linked_node))
+				return arv_gc_integer_get_min (ARV_GC_INTEGER (linked_node), error);
+			else if (ARV_IS_GC_FLOAT (linked_node))
+				return arv_gc_float_get_min (ARV_GC_FLOAT (linked_node), error);
+		}
 		return -G_MAXDOUBLE;
+	}
 
 	value = arv_gc_property_node_get_double (ARV_GC_PROPERTY_NODE (gc_float_node->minimum), &local_error);
 
@@ -273,8 +253,25 @@ arv_gc_float_node_get_max (ArvGcFloat *gc_float, GError **error)
 	GError *local_error = NULL;
 	double value;
 
-	if (gc_float_node->maximum == NULL)
+	if (gc_float_node->maximum == NULL) {
+		ArvGcPropertyNode *value_node;
+
+		value_node = _get_value_node (gc_float_node, &local_error);
+		if (local_error != NULL) {
+			g_propagate_error (error, local_error);
+			return G_MAXDOUBLE;
+		}
+
+		if (ARV_IS_GC_PROPERTY_NODE (value_node)) {
+			ArvGcNode *linked_node = arv_gc_property_node_get_linked_node (value_node);
+
+			if (ARV_IS_GC_INTEGER (linked_node))
+				return arv_gc_integer_get_max (ARV_GC_INTEGER (linked_node), error);
+			else if (ARV_IS_GC_FLOAT (linked_node))
+				return arv_gc_float_get_max (ARV_GC_FLOAT (linked_node), error);
+		}
 		return G_MAXDOUBLE;
+	}
 
 	value = arv_gc_property_node_get_double (ARV_GC_PROPERTY_NODE (gc_float_node->maximum), &local_error);
 
@@ -293,8 +290,26 @@ arv_gc_float_node_get_inc (ArvGcFloat *gc_float, GError **error)
 	GError *local_error = NULL;
 	double value;
 
-	if (gc_float_node->increment == NULL)
+	if (gc_float_node->increment == NULL) {
+		ArvGcPropertyNode *value_node;
+
+		value_node = _get_value_node (gc_float_node, &local_error);
+		if (local_error != NULL) {
+			g_propagate_error (error, local_error);
+			return 1.0;
+		}
+
+		if (ARV_IS_GC_PROPERTY_NODE (value_node)) {
+			ArvGcNode *linked_node = arv_gc_property_node_get_linked_node (value_node);
+
+			if (ARV_IS_GC_INTEGER (linked_node))
+				return arv_gc_integer_get_inc (ARV_GC_INTEGER (linked_node), error);
+			else if (ARV_IS_GC_FLOAT (linked_node))
+				return arv_gc_float_get_inc (ARV_GC_FLOAT (linked_node), error);
+		}
+
 		return 1.0;
+	}
 
 	value = arv_gc_property_node_get_double (ARV_GC_PROPERTY_NODE (gc_float_node->increment), &local_error);
 
