@@ -27,6 +27,8 @@
 
 #include <arvgcintegernode.h>
 #include <arvgcinteger.h>
+#include <arvgcfloat.h>
+#include <arvgcselector.h>
 #include <arvgcvalueindexednode.h>
 #include <arvgcfeaturenodeprivate.h>
 #include <arvgc.h>
@@ -83,6 +85,9 @@ arv_gc_integer_node_post_new_child (ArvDomNode *self, ArvDomNode *child)
 			case ARV_GC_PROPERTY_NODE_TYPE_P_VALUE_DEFAULT:
 				node->value_default = property_node;
 				break;
+			case ARV_GC_PROPERTY_NODE_TYPE_P_SELECTED:
+				node->selecteds = g_slist_prepend (node->selecteds, property_node);
+				break;
 			default:
 				ARV_DOM_NODE_CLASS (parent_class)->post_new_child (self, child);
 				break;
@@ -128,39 +133,6 @@ _get_value_node (ArvGcIntegerNode *gc_integer_node, GError **error)
 	return NULL;
 }
 
-static GType
-arv_gc_integer_node_get_value_type (ArvGcFeatureNode *node)
-{
-	return G_TYPE_INT64;
-}
-
-static void
-arv_gc_integer_node_set_value_from_string (ArvGcFeatureNode *node, const char *string, GError **error)
-{
-	arv_gc_integer_set_value (ARV_GC_INTEGER (node), g_ascii_strtoll (string, NULL, 0), error);
-}
-
-static const char *
-arv_gc_integer_node_get_value_as_string (ArvGcFeatureNode *node, GError **error)
-{
-	ArvGcIntegerNode *integer_node = ARV_GC_INTEGER_NODE (node);
-	ArvGcPropertyNode *value_node;
-	GError *local_error = NULL;
-	const char *string;
-
-	value_node = _get_value_node (integer_node, error);
-	if (value_node == NULL)
-		return NULL;
-
-	string = arv_gc_property_node_get_string (value_node, &local_error);
-	if (local_error != NULL) {
-		g_propagate_error (error, local_error);
-		return NULL;
-	}
-
-	return string;
-}
-
 /* ArvGcIntegerNode implementation */
 
 ArvGcNode *
@@ -185,7 +157,9 @@ arv_gc_integer_node_finalize (GObject *object)
 
 	parent_class->finalize (object);
 
-	g_slist_free (gc_integer_node->value_indexed_nodes);
+	g_clear_pointer (&gc_integer_node->value_indexed_nodes, g_slist_free);
+	g_clear_pointer (&gc_integer_node->selecteds, g_slist_free);
+	g_clear_pointer (&gc_integer_node->selected_features, g_slist_free);
 }
 
 static void
@@ -193,7 +167,6 @@ arv_gc_integer_node_class_init (ArvGcIntegerNodeClass *this_class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (this_class);
 	ArvDomNodeClass *dom_node_class = ARV_DOM_NODE_CLASS (this_class);
-	ArvGcFeatureNodeClass *gc_feature_node_class = ARV_GC_FEATURE_NODE_CLASS (this_class);
 
 	parent_class = g_type_class_peek_parent (this_class);
 
@@ -201,9 +174,6 @@ arv_gc_integer_node_class_init (ArvGcIntegerNodeClass *this_class)
 	dom_node_class->get_node_name = arv_gc_integer_node_get_node_name;
 	dom_node_class->post_new_child = arv_gc_integer_node_post_new_child;
 	dom_node_class->pre_remove_child = arv_gc_integer_node_pre_remove_child;
-	gc_feature_node_class->get_value_type = arv_gc_integer_node_get_value_type;
-	gc_feature_node_class->set_value_from_string = arv_gc_integer_node_set_value_from_string;
-	gc_feature_node_class->get_value_as_string = arv_gc_integer_node_get_value_as_string;
 }
 
 /* ArvGcInteger interface implementation */
@@ -253,8 +223,26 @@ arv_gc_integer_node_get_min (ArvGcInteger *gc_integer, GError **error)
 	GError *local_error = NULL;
 	gint64 value;
 
-	if (gc_integer_node->minimum == NULL)
+	if (gc_integer_node->minimum == NULL) {
+		ArvGcPropertyNode *value_node;
+
+		value_node = _get_value_node (gc_integer_node, &local_error);
+		if (local_error != NULL) {
+			g_propagate_error (error, local_error);
+			return G_MININT64;
+		}
+
+		if (ARV_IS_GC_PROPERTY_NODE (value_node)) {
+			ArvGcNode *linked_node = arv_gc_property_node_get_linked_node (value_node);
+
+			if (ARV_IS_GC_INTEGER (linked_node))
+				return arv_gc_integer_get_min (ARV_GC_INTEGER (linked_node), error);
+			else if (ARV_IS_GC_FLOAT (linked_node))
+				return arv_gc_float_get_min (ARV_GC_FLOAT (linked_node), error);
+		}
+
 		return G_MININT64;
+	}
 
 	value = arv_gc_property_node_get_int64 (ARV_GC_PROPERTY_NODE (gc_integer_node->minimum), &local_error);
 
@@ -273,8 +261,26 @@ arv_gc_integer_node_get_max (ArvGcInteger *gc_integer, GError **error)
 	GError *local_error = NULL;
 	gint64 value;
 
-	if (gc_integer_node->maximum == NULL)
+	if (gc_integer_node->maximum == NULL) {
+		ArvGcPropertyNode *value_node;
+
+		value_node = _get_value_node (gc_integer_node, &local_error);
+		if (local_error != NULL) {
+			g_propagate_error (error, local_error);
+			return G_MAXINT64;
+		}
+
+		if (ARV_IS_GC_PROPERTY_NODE (value_node)) {
+			ArvGcNode *linked_node = arv_gc_property_node_get_linked_node (value_node);
+
+			if (ARV_IS_GC_INTEGER (linked_node))
+				return arv_gc_integer_get_max (ARV_GC_INTEGER (linked_node), error);
+			else if (ARV_IS_GC_FLOAT (linked_node))
+				return arv_gc_float_get_max (ARV_GC_FLOAT (linked_node), error);
+		}
+
 		return G_MAXINT64;
+	}
 
 	value = arv_gc_property_node_get_int64 (ARV_GC_PROPERTY_NODE (gc_integer_node->maximum), &local_error);
 
@@ -293,8 +299,26 @@ arv_gc_integer_node_get_inc (ArvGcInteger *gc_integer, GError **error)
 	GError *local_error = NULL;
 	gint64 value;
 
-	if (gc_integer_node->increment == NULL)
+	if (gc_integer_node->increment == NULL) {
+		ArvGcPropertyNode *value_node;
+
+		value_node = _get_value_node (gc_integer_node, &local_error);
+		if (local_error != NULL) {
+			g_propagate_error (error, local_error);
+			return 1;
+		}
+
+		if (ARV_IS_GC_PROPERTY_NODE (value_node)) {
+			ArvGcNode *linked_node = arv_gc_property_node_get_linked_node (value_node);
+
+			if (ARV_IS_GC_INTEGER (linked_node))
+				return arv_gc_integer_get_inc (ARV_GC_INTEGER (linked_node), error);
+			else if (ARV_IS_GC_FLOAT (linked_node))
+				return arv_gc_float_get_inc (ARV_GC_FLOAT (linked_node), error);
+		}
+
 		return 1;
+	}
 
 	value = arv_gc_property_node_get_int64 (ARV_GC_PROPERTY_NODE (gc_integer_node->increment), &local_error);
 
@@ -369,5 +393,28 @@ arv_gc_integer_node_integer_interface_init (ArvGcIntegerInterface *interface)
 	interface->impose_max = arv_gc_integer_node_impose_max;
 }
 
+const GSList *
+arv_gc_integer_node_get_selected_features (ArvGcSelector *selector)
+{
+	ArvGcIntegerNode *integer = ARV_GC_INTEGER_NODE (selector);
+	GSList *iter;
+
+	g_clear_pointer (&integer->selected_features, g_slist_free);
+	for (iter = integer->selecteds; iter != NULL; iter = iter->next) {
+		ArvGcFeatureNode *feature_node = ARV_GC_FEATURE_NODE (arv_gc_property_node_get_linked_node (iter->data));
+		if (ARV_IS_GC_FEATURE_NODE (feature_node))
+			integer->selected_features = g_slist_prepend (integer->selected_features, feature_node);
+	}
+
+	return integer->selected_features;
+}
+
+static void
+arv_gc_integer_node_selector_interface_init (ArvGcSelectorInterface *interface)
+{
+	interface->get_selected_features = arv_gc_integer_node_get_selected_features;
+}
+
 G_DEFINE_TYPE_WITH_CODE (ArvGcIntegerNode, arv_gc_integer_node, ARV_TYPE_GC_FEATURE_NODE,
-			 G_IMPLEMENT_INTERFACE (ARV_TYPE_GC_INTEGER, arv_gc_integer_node_integer_interface_init))
+			 G_IMPLEMENT_INTERFACE (ARV_TYPE_GC_INTEGER, arv_gc_integer_node_integer_interface_init)
+			 G_IMPLEMENT_INTERFACE (ARV_TYPE_GC_SELECTOR, arv_gc_integer_node_selector_interface_init))
