@@ -38,6 +38,7 @@
 
 struct _ArvGcPortPrivate {
 	ArvGcPropertyNode *chunk_id;
+	ArvGcPropertyNode *event_id;
 };
 
 G_DEFINE_TYPE_WITH_CODE (ArvGcPort, arv_gc_port, ARV_TYPE_GC_FEATURE_NODE, G_ADD_PRIVATE(ArvGcPort))
@@ -62,6 +63,9 @@ _post_new_child (ArvDomNode *self, ArvDomNode *child)
 			case ARV_GC_PROPERTY_NODE_TYPE_CHUNK_ID:
 				node->priv->chunk_id = property_node;
 				break;
+			case ARV_GC_PROPERTY_NODE_TYPE_EVENT_ID:
+				node->priv->event_id = property_node;
+				break;
 			default:
 				ARV_DOM_NODE_CLASS (arv_gc_port_parent_class)->post_new_child (self, child);
 				break;
@@ -96,12 +100,37 @@ arv_gc_port_read (ArvGcPort *port, void *buffer, guint64 address, guint64 length
 	ArvGc *genicam;
 
 	g_return_if_fail (ARV_IS_GC_PORT (port));
-	g_return_if_fail (error == NULL || *error == NULL);
 	g_return_if_fail (buffer != NULL);
 
 	genicam = arv_gc_node_get_genicam (ARV_GC_NODE (port));
 
-	if (port->priv->chunk_id == NULL) {
+	if (port->priv->chunk_id != NULL) {
+		ArvBuffer *chunk_data_buffer;
+
+		chunk_data_buffer = arv_gc_get_buffer (genicam);
+
+		if (!ARV_IS_BUFFER (chunk_data_buffer)) {
+			g_set_error (error, ARV_CHUNK_PARSER_ERROR, ARV_CHUNK_PARSER_ERROR_BUFFER_NOT_FOUND,
+				     "[ArvGcPort::read] Buffer not found");
+		} else {
+			char *chunk_data;
+			size_t chunk_data_size;
+			guint chunk_id;
+
+			chunk_id = g_ascii_strtoll (arv_gc_property_node_get_string (port->priv->chunk_id, NULL), NULL, 16);
+			chunk_data = (char *) arv_buffer_get_chunk_data (chunk_data_buffer, chunk_id, &chunk_data_size);
+
+			if (chunk_data != NULL) {
+				memcpy (buffer, chunk_data + address, MIN (chunk_data_size - address, length));
+			} else {
+				g_set_error (error, ARV_CHUNK_PARSER_ERROR, ARV_CHUNK_PARSER_ERROR_CHUNK_NOT_FOUND,
+					     "[ArvGcPort::read] Chunk 0x%08x not found", chunk_id);
+			}
+		}
+	} else if (port->priv->event_id != NULL) {
+		g_set_error (error, ARV_GC_ERROR, ARV_GC_ERROR_NO_EVENT_IMPLEMENTATION,
+			     "[ArvGcPort::read] Event support is not implemented");
+	} else {
 		ArvDevice *device;
 
 		device = arv_gc_get_device (genicam);
@@ -118,34 +147,8 @@ arv_gc_port_read (ArvGcPort *port, void *buffer, guint64 address, guint64 length
 			} else
 				arv_device_read_memory (device, address, length, buffer, error);
 		} else {
-			if (error != NULL && *error == NULL)
-				*error = g_error_new (ARV_CHUNK_PARSER_ERROR, ARV_CHUNK_PARSER_STATUS_INVALID_FEATURE_NAME,
-						      "[ArvGcPort::read] Invalid feature name");
-		}
-	} else {
-		ArvBuffer *chunk_data_buffer;
-
-		chunk_data_buffer = arv_gc_get_buffer (genicam);
-
-		if (!ARV_IS_BUFFER (chunk_data_buffer)) {
-			if (error != NULL && *error == NULL)
-				*error = g_error_new (ARV_CHUNK_PARSER_ERROR, ARV_CHUNK_PARSER_STATUS_BUFFER_NOT_FOUND,
-						      "[ArvGcPort::read] Buffer not found");
-		} else {
-			char *chunk_data;
-			size_t chunk_data_size;
-			guint chunk_id;
-
-			chunk_id = g_ascii_strtoll (arv_gc_property_node_get_string (port->priv->chunk_id, NULL), NULL, 16);
-			chunk_data = (char *) arv_buffer_get_chunk_data (chunk_data_buffer, chunk_id, &chunk_data_size);
-
-			if (chunk_data != NULL) {
-				memcpy (buffer, chunk_data + address, MIN (chunk_data_size - address, length));
-			} else {
-				if (error != NULL && *error == NULL)
-					*error = g_error_new (ARV_CHUNK_PARSER_ERROR, ARV_CHUNK_PARSER_STATUS_CHUNK_NOT_FOUND,
-							      "[ArvGcPort::read] Chunk 0x%08x not found", chunk_id);
-			}
+			g_set_error (error, ARV_GC_ERROR, ARV_GC_ERROR_NO_DEVICE_SET,
+				     "[ArvGcPort::read] No device set");
 		}
 	}
 }
@@ -157,14 +160,39 @@ arv_gc_port_write (ArvGcPort *port, void *buffer, guint64 address, guint64 lengt
 	ArvDevice *device;
 
 	g_return_if_fail (ARV_IS_GC_PORT (port));
-	g_return_if_fail (error == NULL || *error == NULL);
 	g_return_if_fail (buffer != NULL);
 
 	genicam = arv_gc_node_get_genicam (ARV_GC_NODE (port));
 
 	arv_gc_feature_node_increment_change_count (ARV_GC_FEATURE_NODE (port));
 
-	if (port->priv->chunk_id == NULL) {
+	if (port->priv->chunk_id != NULL) {
+		ArvBuffer *chunk_data_buffer;
+
+		chunk_data_buffer = arv_gc_get_buffer (genicam);
+
+		if (!ARV_IS_BUFFER (chunk_data_buffer)) {
+			g_set_error (error, ARV_CHUNK_PARSER_ERROR, ARV_CHUNK_PARSER_ERROR_BUFFER_NOT_FOUND,
+				     "[ArvGcPort::write] Buffer not found");
+		} else {
+			char *chunk_data;
+			size_t chunk_data_size;
+			guint chunk_id;
+
+			chunk_id = g_ascii_strtoll (arv_gc_property_node_get_string (port->priv->chunk_id, NULL), NULL, 16);
+			chunk_data = (char *) arv_buffer_get_chunk_data (chunk_data_buffer, chunk_id, &chunk_data_size);
+
+			if (chunk_data != NULL) {
+				memcpy (chunk_data + address, buffer, MIN (chunk_data_size - address, length));
+			} else {
+				g_set_error (error, ARV_CHUNK_PARSER_ERROR, ARV_CHUNK_PARSER_ERROR_CHUNK_NOT_FOUND,
+					     "[ArvGcPort::write] Chunk 0x%08x not found", chunk_id);
+			}
+		}
+	} else if (port->priv->event_id != NULL) {
+		g_set_error (error, ARV_GC_ERROR, ARV_GC_ERROR_NO_EVENT_IMPLEMENTATION,
+			     "[ArvGcPort::read] Event support is not implemented");
+	} else {
 		device = arv_gc_get_device (genicam);
 
 		if (ARV_IS_DEVICE (device)) {
@@ -181,34 +209,8 @@ arv_gc_port_write (ArvGcPort *port, void *buffer, guint64 address, guint64 lengt
 			} else
 				arv_device_write_memory (device, address, length, buffer, error);
 		} else {
-			if (error != NULL && *error == NULL)
-				*error = g_error_new (ARV_CHUNK_PARSER_ERROR, ARV_CHUNK_PARSER_STATUS_INVALID_FEATURE_NAME,
-						      "[ArvGcPort::write] Invalid feature name");
-		}
-	} else {
-		ArvBuffer *chunk_data_buffer;
-
-		chunk_data_buffer = arv_gc_get_buffer (genicam);
-
-		if (!ARV_IS_BUFFER (chunk_data_buffer)) {
-			if (error != NULL && *error == NULL)
-				*error = g_error_new (ARV_CHUNK_PARSER_ERROR, ARV_CHUNK_PARSER_STATUS_BUFFER_NOT_FOUND,
-						      "[ArvGcPort::write] Buffer not found");
-		} else {
-			char *chunk_data;
-			size_t chunk_data_size;
-			guint chunk_id;
-
-			chunk_id = g_ascii_strtoll (arv_gc_property_node_get_string (port->priv->chunk_id, NULL), NULL, 16);
-			chunk_data = (char *) arv_buffer_get_chunk_data (chunk_data_buffer, chunk_id, &chunk_data_size);
-
-			if (chunk_data != NULL) {
-				memcpy (chunk_data + address, buffer, MIN (chunk_data_size - address, length));
-			} else {
-				if (error != NULL && *error == NULL)
-					*error = g_error_new (ARV_CHUNK_PARSER_ERROR, ARV_CHUNK_PARSER_STATUS_CHUNK_NOT_FOUND,
-							      "[ArvGcPort::write] Chunk 0x%08x not found", chunk_id);
-			}
+			g_set_error (error, ARV_GC_ERROR, ARV_GC_ERROR_NO_DEVICE_SET,
+				     "[ArvGcPort::read] No device set");
 		}
 	}
 }
