@@ -107,6 +107,8 @@ arv_gc_property_node_get_node_name (ArvDomNode *node)
 			return "CommandValue";
 		case ARV_GC_PROPERTY_NODE_TYPE_CHUNK_ID:
 			return "ChunkID";
+		case ARV_GC_PROPERTY_NODE_TYPE_EVENT_ID:
+			return "EventID";
 		case ARV_GC_PROPERTY_NODE_TYPE_VALUE_DEFAULT:
 			return "ValueDefault";
 
@@ -122,6 +124,8 @@ arv_gc_property_node_get_node_name (ArvDomNode *node)
 			return "pIsAvailable";
 		case ARV_GC_PROPERTY_NODE_TYPE_P_IS_LOCKED:
 			return "pIsLocked";
+		case ARV_GC_PROPERTY_NODE_TYPE_P_SELECTED:
+			return "pSelected";
 		case ARV_GC_PROPERTY_NODE_TYPE_P_MINIMUM:
 			return "pMin";
 		case ARV_GC_PROPERTY_NODE_TYPE_P_MAXIMUM:
@@ -457,7 +461,7 @@ arv_gc_property_node_get_node_type (ArvGcPropertyNode *node)
  * arv_gc_property_node_get_linked_node:
  * @node: a #ArvGcPropertyNode
  *
- * Returns: (transfer none): the #ArvGcNode which @node points to.
+ * Returns: (transfer none): the #ArvGcNode which @node points to, %NULL if the property is not a pointer.
  */
 
 ArvGcNode *
@@ -466,7 +470,9 @@ arv_gc_property_node_get_linked_node (ArvGcPropertyNode *node)
 	ArvGc *genicam;
 
 	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (node), NULL);
-	g_return_val_if_fail (node->type > ARV_GC_PROPERTY_NODE_TYPE_P_UNKNONW, NULL);
+
+	if (node->type <= ARV_GC_PROPERTY_NODE_TYPE_P_UNKNONW)
+		return NULL;
 
 	genicam = arv_gc_node_get_genicam (ARV_GC_NODE (node));
 	return arv_gc_get_node (genicam, _get_value_data (node));
@@ -615,6 +621,12 @@ arv_gc_property_node_new_p_is_locked (void)
 	return arv_gc_property_node_new (ARV_GC_PROPERTY_NODE_TYPE_P_IS_LOCKED);
 }
 
+ArvGcNode *
+arv_gc_property_node_new_p_selected (void)
+{
+	return arv_gc_property_node_new (ARV_GC_PROPERTY_NODE_TYPE_P_SELECTED);
+}
+
 ArvGcNode *
 arv_gc_property_node_new_length (void)
 {
@@ -675,12 +687,61 @@ arv_gc_property_node_new_access_mode (void)
 	return arv_gc_property_node_new (ARV_GC_PROPERTY_NODE_TYPE_ACCESS_MODE);
 }
 
+ArvGcNode *
+arv_gc_property_node_new_imposed_access_mode (void)
+{
+	return arv_gc_property_node_new (ARV_GC_PROPERTY_NODE_TYPE_IMPOSED_ACCESS_MODE);
+}
+
+ArvGcAccessMode
+arv_gc_property_node_get_access_mode (ArvGcPropertyNode *self, ArvGcAccessMode default_value)
+{
+	const char *value;
+
+	if (self == NULL)
+		return default_value;
+
+	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (self), default_value);
+	g_return_val_if_fail (self->type == ARV_GC_PROPERTY_NODE_TYPE_ACCESS_MODE ||
+			      self->type == ARV_GC_PROPERTY_NODE_TYPE_IMPOSED_ACCESS_MODE, default_value);
+
+	value = _get_value_data (self);
+
+	if (g_strcmp0 (value, "RO") == 0)
+		return ARV_GC_ACCESS_MODE_RO;
+	else if (g_strcmp0 (value, "WO") == 0)
+		return ARV_GC_ACCESS_MODE_WO;
+
+	return ARV_GC_ACCESS_MODE_RW;
+}
+
 ArvGcNode *
 arv_gc_property_node_new_cachable (void)
 {
 	return arv_gc_property_node_new (ARV_GC_PROPERTY_NODE_TYPE_CACHABLE);
 }
 
+ArvGcCachable
+arv_gc_property_node_get_cachable (ArvGcPropertyNode *self, ArvGcCachable default_value)
+{
+	const char *value;
+
+	if (self == NULL)
+		return default_value;
+
+	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (self), default_value);
+	g_return_val_if_fail (self->type == ARV_GC_PROPERTY_NODE_TYPE_CACHABLE, default_value);
+
+	value = _get_value_data (self);
+
+	if (g_strcmp0 (value, "WriteAround") == 0)
+		return ARV_GC_CACHABLE_WRITE_AROUND;
+	else if (g_strcmp0 (value, "WriteThrough") == 0)
+		return ARV_GC_CACHABLE_WRITE_THROUGH;
+
+	return ARV_GC_CACHABLE_NO_CACHE;
+}
+
 ArvGcNode *
 arv_gc_property_node_new_polling_time (void)
 {
@@ -693,24 +754,80 @@ arv_gc_property_node_new_endianess (void)
 	return arv_gc_property_node_new (ARV_GC_PROPERTY_NODE_TYPE_ENDIANESS);
 }
 
+guint
+arv_gc_property_node_get_endianess (ArvGcPropertyNode *self, guint default_value)
+{
+	if (self == NULL)
+		return default_value;
+
+	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (self), default_value);
+	g_return_val_if_fail (self->type == ARV_GC_PROPERTY_NODE_TYPE_ENDIANESS, default_value);
+
+	if (g_strcmp0 (_get_value_data (self), "BigEndian") == 0)
+		return G_BIG_ENDIAN;
+
+	return G_LITTLE_ENDIAN;
+}
+
 ArvGcNode *
 arv_gc_property_node_new_sign (void)
 {
 	return arv_gc_property_node_new (ARV_GC_PROPERTY_NODE_TYPE_SIGN);
 }
 
+ArvGcSignedness
+arv_gc_property_node_get_sign (ArvGcPropertyNode *self, ArvGcSignedness default_value)
+{
+	if (self == NULL)
+		return default_value;
+
+	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (self), default_value);
+	g_return_val_if_fail (self->type == ARV_GC_PROPERTY_NODE_TYPE_SIGN, default_value);
+
+	if (g_strcmp0 (_get_value_data (self), "Unsigned") == 0)
+		return ARV_GC_SIGNEDNESS_UNSIGNED;
+
+	return ARV_GC_SIGNEDNESS_SIGNED;
+}
+
 ArvGcNode *
 arv_gc_property_node_new_lsb (void)
 {
 	return arv_gc_property_node_new (ARV_GC_PROPERTY_NODE_TYPE_LSB);
 }
 
+guint
+arv_gc_property_node_get_lsb (ArvGcPropertyNode *self, guint default_value)
+{
+	if (self == NULL)
+		return default_value;
+
+	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (self), default_value);
+	g_return_val_if_fail (self->type == ARV_GC_PROPERTY_NODE_TYPE_LSB ||
+			      self->type == ARV_GC_PROPERTY_NODE_TYPE_BIT, default_value);
+
+	return g_ascii_strtoll (_get_value_data (self), NULL, 10);
+}
+
 ArvGcNode *
 arv_gc_property_node_new_msb (void)
 {
 	return arv_gc_property_node_new (ARV_GC_PROPERTY_NODE_TYPE_MSB);
 }
 
+guint
+arv_gc_property_node_get_msb (ArvGcPropertyNode *self, guint default_value)
+{
+	if (self == NULL)
+		return default_value;
+
+	g_return_val_if_fail (ARV_IS_GC_PROPERTY_NODE (self), default_value);
+	g_return_val_if_fail (self->type == ARV_GC_PROPERTY_NODE_TYPE_MSB ||
+			      self->type == ARV_GC_PROPERTY_NODE_TYPE_BIT, default_value);
+
+	return g_ascii_strtoll (_get_value_data (self), NULL, 10);
+}
+
 ArvGcNode *
 arv_gc_property_node_new_bit (void)
 {
@@ -735,6 +852,12 @@ arv_gc_property_node_new_chunk_id (void)
 	return arv_gc_property_node_new (ARV_GC_PROPERTY_NODE_TYPE_CHUNK_ID);
 }
 
+ArvGcNode *
+arv_gc_property_node_new_event_id (void)
+{
+	return arv_gc_property_node_new (ARV_GC_PROPERTY_NODE_TYPE_EVENT_ID);
+}
+
 ArvGcNode *
 arv_gc_property_node_new_value_default (void)
 {
