@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2012 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -46,11 +46,20 @@ arv_gc_register_description_node_set_attribute (ArvDomElement *self, const char*
 	if (strcmp (name, "ModelName") == 0) {
 		g_free (node->model_name);
 		node->model_name = g_strdup (value);
+	} else if (strcmp (name, "VendorName") == 0) {
+		g_free (node->vendor_name);
+		node->vendor_name = g_strdup (value);
 	} else if (strcmp (name, "SchemaMajorVersion") == 0) {
-		node->major_version = g_ascii_strtoll (value, NULL, 0);
+		node->schema_major_version = g_ascii_strtoll (value, NULL, 0);
 	} else if (strcmp (name, "SchemaMinorVersion") == 0) {
-		node->minor_version = g_ascii_strtoll (value, NULL, 0);
+		node->schema_minor_version = g_ascii_strtoll (value, NULL, 0);
 	} else if (strcmp (name, "SchemaSubMinorVersion") == 0) {
+		node->schema_subminor_version = g_ascii_strtoll (value, NULL, 0);
+	} else if (strcmp (name, "MajorVersion") == 0) {
+		node->major_version = g_ascii_strtoll (value, NULL, 0);
+	} else if (strcmp (name, "MinorVersion") == 0) {
+		node->minor_version = g_ascii_strtoll (value, NULL, 0);
+	} else if (strcmp (name, "SubMinorVersion") == 0) {
 		node->subminor_version = g_ascii_strtoll (value, NULL, 0);
 	} else
 		ARV_DOM_ELEMENT_CLASS (parent_class)->set_attribute (self, name, value);
@@ -63,34 +72,61 @@ arv_gc_register_description_node_get_attribute (ArvDomElement *self, const char
 
 	if (strcmp (name, "ModelName") == 0)
 		return node->model_name;
+	else if (strcmp (name, "VendorName") == 0)
+		return node->vendor_name;
 	else
 		return ARV_DOM_ELEMENT_CLASS (parent_class)->get_attribute (self, name);
 }
 
 /* ArvGcRegisterDescriptionNode implementation */
 
+/**
+ * arv_gc_register_description_node_compare_schema_version:
+ * @node: a #ArvGcRegisterDescriptionNode
+ * @major: major version number
+ * @minor: minor version number
+ * @subminor: sub mminor version number
+ *
+ * Compare the Genicam document version to the given version.
+ *
+ * Returns: -1 if document version is lower than the given version, 0 if equal and 1 if greater.
+ *
+ * Since: 0.6.0
+ */
+
+int
+arv_gc_register_description_node_compare_schema_version (ArvGcRegisterDescriptionNode *node,
+							 guint major,
+							 guint minor,
+							 guint subminor)
+{
+	g_return_val_if_fail (ARV_IS_GC_REGISTER_DESCRIPTION_NODE (node), FALSE);
+
+	if (node->schema_major_version < major)
+		return -1;
+	if (node->schema_major_version > major)
+		return 1;
+
+	if (node->schema_minor_version < minor)
+		return -1;
+	if (node->schema_minor_version > minor)
+		return 1;
+
+	if (node->schema_subminor_version < subminor)
+		return -1;
+	if (node->schema_subminor_version > subminor)
+		return 1;
+
+	return 0;
+}
+
 gboolean
 arv_gc_register_description_node_check_schema_version (ArvGcRegisterDescriptionNode *node,
 						       guint required_major,
 						       guint required_minor,
 						       guint required_subminor)
 {
-	g_return_val_if_fail (ARV_IS_GC_REGISTER_DESCRIPTION_NODE (node), FALSE);
-
-	if (node->major_version < required_major)
-		return FALSE;
-	if (node->major_version > required_major)
-		return TRUE;
-
-	if (node->minor_version < required_minor)
-		return FALSE;
-	if (node->minor_version > required_minor)
-		return FALSE;
-
-	if (node->subminor_version < required_subminor)
-		return FALSE;
-
-	return TRUE;
+	return arv_gc_register_description_node_compare_schema_version (node, required_major, required_minor, required_subminor) >= 0;
 }
 
 ArvGcNode *
@@ -106,9 +142,9 @@ arv_gc_register_description_node_new (void)
 static void
 arv_gc_register_description_node_init (ArvGcRegisterDescriptionNode *gc_register_description_node)
 {
-	gc_register_description_node->major_version = 0;
-	gc_register_description_node->minor_version = 0;
-	gc_register_description_node->subminor_version = 0;
+	gc_register_description_node->schema_major_version = 0;
+	gc_register_description_node->schema_minor_version = 0;
+	gc_register_description_node->schema_subminor_version = 0;
 }
 
 static void
@@ -117,6 +153,7 @@ arv_gc_register_description_node_finalize (GObject *object)
 	ArvGcRegisterDescriptionNode *node = ARV_GC_REGISTER_DESCRIPTION_NODE (object);
 
 	g_free (node->model_name);
+	g_free (node->vendor_name);
 
 	parent_class->finalize (object);
 }
