@@ -34,37 +34,6 @@
 
 G_BEGIN_DECLS
 
-/**
- * ArvGcSign:
- * @ARV_GC_SIGN_SIGNED: signed integer
- * @ARV_GC_SIGN_UNSIGNED: unsigned integer
- */
-
-typedef enum
-{
-	ARV_GC_SIGN_SIGNED,
-	ARV_GC_SIGN_UNSIGNED
-} ArvGcSign;
-
-/**
- * ArvGcRegisterNodeType:
- * @ARV_GC_REGISTER_NODE_TYPE_REGISTER: Register node
- * @ARV_GC_REGISTER_NODE_TYPE_INTEGER: IntReg node
- * @ARV_GC_REGISTER_NODE_TYPE_MASKED_INTEGER: MaskedIntReg node
- * @ARV_GC_REGISTER_NODE_TYPE_FLOAT: FloatReg node
- * @ARV_GC_REGISTER_NODE_TYPE_STRING: StringReg node
- * @ARV_GC_REGISTER_NODE_TYPE_STRUCT_REGISTER: StructReg node
- */
-
-typedef enum {
-       ARV_GC_REGISTER_NODE_TYPE_REGISTER,
-       ARV_GC_REGISTER_NODE_TYPE_INTEGER,
-       ARV_GC_REGISTER_NODE_TYPE_MASKED_INTEGER,
-       ARV_GC_REGISTER_NODE_TYPE_FLOAT,
-       ARV_GC_REGISTER_NODE_TYPE_STRING,
-       ARV_GC_REGISTER_NODE_TYPE_STRUCT_REGISTER
-} ArvGcRegisterNodeType;
-
 #define ARV_TYPE_GC_REGISTER_NODE             (arv_gc_register_node_get_type ())
 #define ARV_GC_REGISTER_NODE(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), ARV_TYPE_GC_REGISTER_NODE, ArvGcRegisterNode))
 #define ARV_GC_REGISTER_NODE_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), ARV_TYPE_GC_REGISTER_NODE, ArvGcRegisterNodeClass))
@@ -77,25 +46,16 @@ typedef struct _ArvGcRegisterNodeClass ArvGcRegisterNodeClass;
 struct _ArvGcRegisterNode {
 	ArvGcFeatureNode	node;
 
-	ArvGcRegisterNodeType type;
-	GType value_type;
-
 	GSList *addresses;
 	GSList *swiss_knives;
 	ArvGcPropertyNode *index;
 	ArvGcPropertyNode *length;
 	ArvGcPropertyNode *port;
-	ArvGcPropertyNode *access_mode;
 	ArvGcPropertyNode *cachable;
 	ArvGcPropertyNode *polling_time;
 	ArvGcPropertyNode *endianess;
-	ArvGcPropertyNode *sign;
-	ArvGcPropertyNode *lsb;
-	ArvGcPropertyNode *msb;
 
-	GSList *invalidators;		/* ArvGcPropertyNode list */
-
-	ArvGcCachable default_cachable;
+	GSList *invalidators;		/* #ArvGcPropertyNode */
 
 	gboolean cached;
 	GHashTable *caches;
@@ -107,21 +67,14 @@ struct _ArvGcRegisterNode {
 
 struct _ArvGcRegisterNodeClass {
 	ArvGcFeatureNodeClass parent_class;
+
+	ArvGcCachable default_cachable;
 };
 
 GType 		arv_gc_register_node_get_type 			(void);
 ArvGcNode * 	arv_gc_register_node_new 			(void);
-ArvGcNode * 	arv_gc_register_node_new_integer 		(void);
-ArvGcNode * 	arv_gc_register_node_new_masked_integer 	(void);
-ArvGcNode * 	arv_gc_register_node_new_float	 		(void);
-ArvGcNode * 	arv_gc_register_node_new_string 		(void);
-ArvGcNode * 	arv_gc_register_node_new_struct_register	(void);
 
-gint64 		arv_gc_register_node_get_masked_integer_value 	(ArvGcRegisterNode *gc_register_node,
-								 guint lsb, guint msb, ArvGcSignedness signedness,
-								 GError **error);
-void 		arv_gc_register_node_set_masked_integer_value 	(ArvGcRegisterNode *gc_register_node,
-								 guint lsb, guint msb, gint64 value, GError **error);
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (ArvGcRegisterNode, g_object_unref)
 
 G_END_DECLS
 
