@@ -218,7 +218,7 @@ _send_cmd_and_receive_ack (ArvGvDeviceIOData *io_data, ArvGvcpCommand command,
 								  ARV_GV_DEVICE_BUFFER_SIZE, NULL, &local_error);
 				else
 					count = 0;
-				success = success && (count >= ack_size);
+				success = success && (count >= sizeof (ArvGvcpHeader));
 
 				if (success) {
 					ArvGvcpPacketType packet_type;
@@ -231,7 +231,8 @@ _send_cmd_and_receive_ack (ArvGvDeviceIOData *io_data, ArvGvcpCommand command,
 					command = arv_gvcp_packet_get_command (ack_packet);
 					packet_id = arv_gvcp_packet_get_packet_id (ack_packet);
 
-					if (command == ARV_GVCP_COMMAND_PENDING_ACK) {
+					if (command == ARV_GVCP_COMMAND_PENDING_ACK &&
+					    count >= arv_gvcp_packet_get_pending_ack_size ()) {
 						gint64 pending_ack_timeout_ms = arv_gvcp_packet_get_pending_ack_timeout (ack_packet);
 						pending_ack = TRUE;
 						expected_answer = FALSE;
@@ -251,7 +252,8 @@ _send_cmd_and_receive_ack (ArvGvDeviceIOData *io_data, ArvGvcpCommand command,
 					} else  {
 						expected_answer = packet_type == ARV_GVCP_PACKET_TYPE_ACK &&
 							command == ack_command &&
-							packet_id == io_data->packet_id;
+							packet_id == io_data->packet_id &&
+							count >= ack_size;
 						if (!expected_answer) {
 							arv_debug_device ("[GvDevice::%s] Unexpected answer (0x%04x)", operation,
 									  packet_type);
@@ -262,6 +264,8 @@ _send_cmd_and_receive_ack (ArvGvDeviceIOData *io_data, ArvGvcpCommand command,
 					if (local_error != NULL)
 						arv_warning_device ("[GvDevice::%s] Ack reception error: %s", operation,
 								    local_error->message);
+					else
+						arv_warning_device ("[GvDevice::%s] Ack reception timeout", operation);
 					g_clear_error (&local_error);
 				}
 			} while (pending_ack || (!expected_answer && timeout_ms > 0));
@@ -318,11 +322,11 @@ _send_cmd_and_receive_ack (ArvGvDeviceIOData *io_data, ArvGvcpCommand command,
 		if (error != NULL && *error == NULL) {
 			if (command_error != ARV_GVCP_ERROR_NONE)
 				*error = g_error_new (ARV_DEVICE_ERROR, ARV_STATUS_PROTOCOL_ERROR,
-						      "[GvDevice::%s] GigEVision error: %s", operation,
+						      "GigEVision %s error (%s)", operation,
 						      arv_gvcp_error_to_string (command_error));
 			else
 				*error = g_error_new (ARV_DEVICE_ERROR, ARV_STATUS_TIMEOUT,
-						      "[GvDevice::%s] Timeout", operation);
+						      "GigEVision %s timeout", operation);
 		}
 	}
 
@@ -830,14 +834,45 @@ arv_gv_device_load_genicam (ArvGvDevice *gv_device)
 					      "<AccessMode>RO</AccessMode>"
 					      "<pPort>Device</pPort>"
 					      "</StringReg>", NULL);
-		arv_gc_set_default_node_data (gv_device->priv->genicam, "NumberOfStreamChannels",
-					      "<IntReg Name=\"NumberOfStreamChannels\">"
+		arv_gc_set_default_node_data (gv_device->priv->genicam, "GevStreamChannelCount",
+					      "<IntReg Name=\"GevStreamChannelCount\">"
 					      "<Address>0x904</Address>"
 					      "<Length>4</Length>"
 					      "<AccessMode>RO</AccessMode>"
 					      "<Endianess>BigEndian</Endianess>"
 					      "<pPort>Device</pPort>"
 					      "</IntReg>", NULL);
+		arv_gc_set_default_node_data (gv_device->priv->genicam, "GevTimestampTickFrequency",
+					      "<Integer Name=\"GevTimestampTickFrequency\">"
+					      "<pValue>ArvGevTimestampTickFrequencyCalc</pValue>"
+					      "</Integer>",
+					      "<IntSwissKnife Name=\"ArvGevTimestampTickFrequencyCalc\">"
+					      "<pVariable Name=\"HIGH\">ArvGevTimestampTickFrequencyHigh</pVariable>"
+					      "<pVariable Name=\"LOW\">ArvGevTimestampTickFrequencyLow</pVariable>"
+					      "<Formula>(HIGH&lt;&lt; 32) | LOW</Formula>"
+					      "</IntSwissKnife>",
+					      "<MaskedIntReg Name=\"ArvGevTimestampTickFrequencyHigh\">"
+					      "<Visibility>Invisible</Visibility>"
+					      "<Address>0x93C</Address>"
+					      "<Length>4</Length>"
+					      "<AccessMode>RO</AccessMode>"
+					      "<pPort>Device</pPort>"
+					      "<LSB>31</LSB>"
+					      "<MSB>0</MSB>"
+					      "<Sign>Unsigned</Sign>"
+					      "<Endianess>BigEndian</Endianess>"
+					      "</MaskedIntReg>",
+					      "<MaskedIntReg Name=\"ArvGevTimestampTickFrequencyLow\">"
+					      "<Visibility>Invisible</Visibility>"
+					      "<Address>0x940</Address>"
+					      "<Length>4</Length>"
+					      "<AccessMode>RO</AccessMode>"
+					      "<pPort>Device</pPort>"
+					      "<LSB>31</LSB>"
+					      "<MSB>0</MSB>"
+					      "<Sign>Unsigned</Sign>"
+					      "<Endianess>BigEndian</Endianess>"
+					      "</MaskedIntReg>", NULL);
 		arv_gc_set_default_node_data (gv_device->priv->genicam, "GevSCPHostPort",
 					      "<Integer Name=\"GevSCPHostPort\">"
 					      "  <Visibility>Expert</Visibility>"
@@ -997,7 +1032,7 @@ arv_gv_device_create_stream (ArvDevice *device, ArvStreamCallback callback, void
 	GInetAddress *interface_address;
 	GInetAddress *device_address;
 
-	n_stream_channels = arv_device_get_integer_feature_value (device, "NumberOfStreamChannels", NULL);
+	n_stream_channels = arv_device_get_integer_feature_value (device, "GevStreamChannelCount", NULL);
 	arv_debug_device ("[GvDevice::create_stream] Number of stream channels = %d", n_stream_channels);
 
 	if (n_stream_channels < 1)
