@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2016 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -52,7 +52,7 @@ GSocketAddress *	arv_gv_device_get_interface_address  		(ArvGvDevice *device);
 GSocketAddress *	arv_gv_device_get_device_address  		(ArvGvDevice *device);
 
 guint			arv_gv_device_get_packet_size 			(ArvGvDevice *gv_device);
-void			arv_gv_device_set_packet_size 			(ArvGvDevice *gv_device, guint packet_size);
+void			arv_gv_device_set_packet_size 			(ArvGvDevice *gv_device, gint packet_size);
 guint			arv_gv_device_auto_packet_size 			(ArvGvDevice *gv_device);
 
 ArvGvStreamOption	arv_gv_device_get_stream_options		(ArvGvDevice *gv_device);
