@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2016 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,13 +20,13 @@
  * Author: Emmanuel Pacaud <emmanuel@gnome.org>
  */
 
-/**
+/*
  * SECTION: arvuvcp
  * @short_description: USB3Vision control packet handling
  */
 
-#include <arvuvcp.h>
-#include <arvenumtypes.h>
+#include <arvuvcpprivate.h>
+#include <arvenumtypesprivate.h>
 #include <arvdebug.h>
 #include <arvstr.h>
 #include <string.h>
