@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2016 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,9 +28,9 @@
 #include <arvuvstreamprivate.h>
 #include <arvuvdeviceprivate.h>
 #include <arvuvinterfaceprivate.h>
+#include <arvuvcpprivate.h>
 #include <arvgc.h>
 #include <arvdebug.h>
-#include <arvuvcp.h>
 #include <libusb.h>
 #include <string.h>
 #include <arvstr.h>
@@ -39,8 +39,6 @@
 
 #define ARV_UV_DEVICE_N_TRIES_MAX	5
 
-static GObjectClass *parent_class = NULL;
-
 struct _ArvUvDevicePrivate {
 	char *vendor;
 	char *product;
@@ -84,7 +82,7 @@ arv_uv_device_bulk_transfer (ArvUvDevice *uv_device, ArvUvEndpointType endpoint_
 	g_return_val_if_fail (size > 0, FALSE);
 
 	if (uv_device->priv->disconnected) {
-		g_set_error (error, ARV_DEVICE_ERROR, ARV_DEVICE_STATUS_NOT_CONNECTED,
+		g_set_error (error, ARV_DEVICE_ERROR, ARV_STATUS_NOT_CONNECTED,
 			     "Not connected");
 		return FALSE;
 	}
@@ -97,7 +95,7 @@ arv_uv_device_bulk_transfer (ArvUvDevice *uv_device, ArvUvEndpointType endpoint_
 	success = result >= 0;
 
 	if (!success)
-		g_set_error (error, ARV_DEVICE_ERROR, ARV_DEVICE_STATUS_TRANSFER_ERROR,
+		g_set_error (error, ARV_DEVICE_ERROR, ARV_STATUS_TRANSFER_ERROR,
 			     "%s", libusb_error_name (result));
 
 	if (transferred_size != NULL)
@@ -226,7 +224,7 @@ _read_memory (ArvUvDevice *uv_device, guint64 address, guint32 size, void *buffe
 
 	if (!success) {
 		if (error != NULL && *error == NULL)
-			*error = g_error_new (ARV_DEVICE_ERROR, ARV_DEVICE_STATUS_TIMEOUT,
+			*error = g_error_new (ARV_DEVICE_ERROR, ARV_STATUS_TIMEOUT,
 					      "[ArvDevice::read_memory] Timeout");
 	}
 
@@ -358,7 +356,7 @@ _write_memory (ArvUvDevice *uv_device, guint64 address, guint32 size, void *buff
 
 	if (!success) {
 		if (error != NULL && *error == NULL)
-			*error = g_error_new (ARV_DEVICE_ERROR, ARV_DEVICE_STATUS_TIMEOUT,
+			*error = g_error_new (ARV_DEVICE_ERROR, ARV_STATUS_TIMEOUT,
 					      "[ArvDevice::write_memory] Timeout");
 	}
 
@@ -730,6 +728,7 @@ arv_uv_device_new (const char *vendor, const char *product, const char *serial_n
 
 	if ( !_bootstrap (uv_device)){
 		arv_warning_device ("[UvDevice::new] Failed to bootstrap USB device");
+		g_object_unref (uv_device);
 		return NULL;
 	}
 
@@ -742,10 +741,13 @@ arv_uv_device_new (const char *vendor, const char *product, const char *serial_n
 	return ARV_DEVICE (uv_device);
 }
 
+G_DEFINE_TYPE_WITH_CODE (ArvUvDevice, arv_uv_device, ARV_TYPE_DEVICE, G_ADD_PRIVATE (ArvUvDevice))
+
 static void
 arv_uv_device_init (ArvUvDevice *uv_device)
 {
-	uv_device->priv = G_TYPE_INSTANCE_GET_PRIVATE (uv_device, ARV_TYPE_UV_DEVICE, ArvUvDevicePrivate);
+	uv_device->priv = arv_uv_device_get_instance_private (uv_device);
+
 	uv_device->priv->cmd_packet_size_max = 65536 + sizeof (ArvUvcpHeader);
 	uv_device->priv->ack_packet_size_max = 65536 + sizeof (ArvUvcpHeader);
 	uv_device->priv->disconnected = FALSE;
@@ -769,7 +771,7 @@ arv_uv_device_finalize (GObject *object)
 	}
 	libusb_exit (uv_device->priv->usb);
 
-	parent_class->finalize (object);
+	G_OBJECT_CLASS (arv_uv_device_parent_class)->finalize (object);
 }
 
 static void
@@ -778,12 +780,6 @@ arv_uv_device_class_init (ArvUvDeviceClass *uv_device_class)
 	GObjectClass *object_class = G_OBJECT_CLASS (uv_device_class);
 	ArvDeviceClass *device_class = ARV_DEVICE_CLASS (uv_device_class);
 
-#if !GLIB_CHECK_VERSION(2,38,0)
-	g_type_class_add_private (uv_device_class, sizeof (ArvUvDevicePrivate));
-#endif
-
-	parent_class = g_type_class_peek_parent (uv_device_class);
-
 	object_class->finalize = arv_uv_device_finalize;
 
 	device_class->create_stream = arv_uv_device_create_stream;
@@ -794,9 +790,3 @@ arv_uv_device_class_init (ArvUvDeviceClass *uv_device_class)
 	device_class->read_register = arv_uv_device_read_register;
 	device_class->write_register = arv_uv_device_write_register;
 }
-
-#if !GLIB_CHECK_VERSION(2,38,0)
-G_DEFINE_TYPE (ArvUvDevice, arv_uv_device, ARV_TYPE_DEVICE)
-#else
-G_DEFINE_TYPE_WITH_CODE (ArvUvDevice, arv_uv_device, ARV_TYPE_DEVICE, G_ADD_PRIVATE (ArvUvDevice))
-#endif
