@@ -17,6 +17,7 @@ static double arv_option_exposure_time_us = -1;
 static int arv_option_gain = -1;
 static gboolean arv_option_auto_socket_buffer = FALSE;
 static gboolean arv_option_no_packet_resend = FALSE;
+static double arv_option_packet_request_ratio = -1.0;
 static unsigned int arv_option_packet_timeout = 20;
 static unsigned int arv_option_frame_retention = 100;
 static int arv_option_gv_stream_channel = -1;
@@ -82,6 +83,10 @@ static const GOptionEntry arv_option_entries[] =
 		"no-packet-resend",			'r', 0, G_OPTION_ARG_NONE,
 		&arv_option_no_packet_resend,		"No packet resend", NULL
 	},
+	{
+		"packet-request-ratio",			'q', 0, G_OPTION_ARG_DOUBLE,
+		&arv_option_packet_request_ratio,	"Packet resend request limit as a frame packet number ratio [0..2.0]", NULL
+	},
 	{
 		"packet-timeout", 			'p', 0, G_OPTION_ARG_INT,
 		&arv_option_packet_timeout, 		"Packet timeout (ms)", NULL
@@ -154,13 +159,27 @@ new_buffer_cb (ArvStream *stream, ApplicationData *data)
 		if (arv_buffer_get_status (buffer) == ARV_BUFFER_STATUS_SUCCESS)
 			data->buffer_count++;
 
-		if (arv_buffer_get_payload_type (buffer) == ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA &&
-		    data->chunks != NULL) {
+		if (arv_buffer_has_chunks (buffer) && data->chunks != NULL) {
 			int i;
 
-			for (i = 0; data->chunks[i] != NULL; i++)
-				printf ("%s = %" G_GINT64_FORMAT "\n", data->chunks[i],
-					arv_chunk_parser_get_integer_value (data->chunk_parser, buffer, data->chunks[i]));
+			for (i = 0; data->chunks[i] != NULL; i++) {
+				gint64 integer_value;
+				GError *error = NULL;
+
+				integer_value = arv_chunk_parser_get_integer_value (data->chunk_parser, buffer, data->chunks[i], &error);
+				if (error == NULL)
+					printf ("%s = %" G_GINT64_FORMAT "\n", data->chunks[i], integer_value);
+				else {
+					double float_value;
+
+					g_clear_error (&error);
+					float_value = arv_chunk_parser_get_float_value (data->chunk_parser, buffer, data->chunks[i], &error);
+					if (error == NULL)
+						printf ("%s = %g\n", data->chunks[i], float_value);
+					else
+						g_clear_error (&error);
+				}
+			}
 		}
 
 		/* Image processing here */
@@ -231,9 +250,6 @@ main (int argc, char **argv)
 	data.chunks = NULL;
 	data.chunk_parser = NULL;
 
-	arv_g_thread_init (NULL);
-	arv_g_type_init ();
-
 	context = g_option_context_new (NULL);
 	g_option_context_add_main_entries (context, arv_option_entries, NULL);
 
@@ -346,6 +362,11 @@ main (int argc, char **argv)
 					g_object_set (stream,
 						      "packet-resend", ARV_GV_STREAM_PACKET_RESEND_NEVER,
 						      NULL);
+				if (arv_option_packet_request_ratio >= 0.0)
+					g_object_set (stream,
+						      "packet-request-ratio", arv_option_packet_request_ratio,
+						      NULL);
+
 				g_object_set (stream,
 					      "packet-timeout", (unsigned) arv_option_packet_timeout * 1000,
 					      "frame-retention", (unsigned) arv_option_frame_retention * 1000,
