@@ -1,20 +1,6 @@
 #include <glib.h>
 #include <arv.h>
 
-static void
-load_fake_camera_genicam_test (void)
-{
-	const char *genicam_xml;
-	size_t size;
-
-	genicam_xml = arv_get_fake_camera_genicam_xml (&size);
-	g_assert (genicam_xml != NULL);
-	g_assert (size != 0);
-
-	genicam_xml = arv_get_fake_camera_genicam_xml (NULL);
-	g_assert (genicam_xml != NULL);
-}
-
 static void
 trigger_registers_test (void)
 {
@@ -43,7 +29,7 @@ trigger_registers_test (void)
 										 "TriggerActivationRegister")), NULL);
 	g_assert_cmpint (address, ==, ARV_FAKE_CAMERA_REGISTER_TRIGGER_ACTIVATION);
 
-	arv_device_set_string_feature_value (device, "TriggerSelector", "AcquisitionStart");
+	arv_device_set_string_feature_value (device, "TriggerSelector", "AcquisitionStart", NULL);
 
 	address = arv_gc_register_get_address (ARV_GC_REGISTER (node), NULL);
 	g_assert_cmpint (address, ==, ARV_FAKE_CAMERA_REGISTER_TRIGGER_MODE +
@@ -108,7 +94,7 @@ registers_test (void)
 	arv_gc_integer_set_value (ARV_GC_INTEGER (node_a), 0xabcdefaa, NULL);
 
 	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_a), NULL);
-	g_assert_cmpint (value, ==, 0xefaa);
+	g_assert_cmpint (value, ==, -4182);
 
 	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_b), NULL);
 	g_assert_cmpint (value, ==, 0x1010);
@@ -119,11 +105,21 @@ registers_test (void)
 	arv_gc_integer_set_value (ARV_GC_INTEGER (node_c), 0xff, NULL);
 
 	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_c), NULL);
-	g_assert_cmpint (value, ==, 0x1);
+	g_assert_cmpint (value, ==, 1);
 
 	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_b), NULL);
 	g_assert_cmpint (value, ==, 0x1011);
 
+	arv_gc_integer_set_value (ARV_GC_INTEGER (node_b), 0xff, NULL);
+
+	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_b), NULL);
+	g_assert_cmpint (value, ==, 0xff);
+
+	arv_gc_integer_set_value (ARV_GC_INTEGER (node_c), 0x0, NULL);
+
+	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_c), NULL);
+	g_assert_cmpint (value, ==, 0);
+
 	g_object_unref (device);
 }
 
@@ -131,7 +127,6 @@ static void
 fake_device_test (void)
 {
 	ArvDevice *device;
-	ArvDeviceStatus status;
 	int int_value;
 	double dbl_value;
 	double boolean_value;
@@ -139,7 +134,7 @@ fake_device_test (void)
 	gint64 *values;
 	const char **string_values;
 	const char *string_value;
-	int n_values;
+	guint n_values;
 	double float_minimum, float_maximum;
 	const char *genicam;
 	gsize size;
@@ -151,82 +146,79 @@ fake_device_test (void)
 	g_assert (genicam != NULL);
 
 	/* Check default */
-	int_value = arv_device_get_integer_feature_value (device, "Width");
+	int_value = arv_device_get_integer_feature_value (device, "Width", NULL);
 	g_assert_cmpint (int_value, ==, ARV_FAKE_CAMERA_WIDTH_DEFAULT);
 
-	arv_device_set_integer_feature_value (device, "Width", 1024);
-	int_value = arv_device_get_integer_feature_value (device, "Width");
+	arv_device_set_integer_feature_value (device, "Width", 1024, NULL);
+	int_value = arv_device_get_integer_feature_value (device, "Width", NULL);
 	g_assert_cmpint (int_value, ==, 1024);
 
 	/* Check default */
-	int_value = arv_device_get_integer_feature_value (device, "Height");
+	int_value = arv_device_get_integer_feature_value (device, "Height", NULL);
 	g_assert_cmpint (int_value, ==, ARV_FAKE_CAMERA_HEIGHT_DEFAULT);
 
-	arv_device_set_integer_feature_value (device, "Height", 1024);
-	int_value = arv_device_get_integer_feature_value (device, "Height");
+	arv_device_set_integer_feature_value (device, "Height", 1024, NULL);
+	int_value = arv_device_get_integer_feature_value (device, "Height", NULL);
 	g_assert_cmpint (int_value, ==, 1024);
 
-	int_value = arv_device_get_integer_feature_value (device, "BinningHorizontal");
+	int_value = arv_device_get_integer_feature_value (device, "BinningHorizontal", NULL);
 	g_assert_cmpint (int_value, ==, ARV_FAKE_CAMERA_BINNING_HORIZONTAL_DEFAULT);
-	int_value = arv_device_get_integer_feature_value (device, "BinningVertical");
+	int_value = arv_device_get_integer_feature_value (device, "BinningVertical", NULL);
 	g_assert_cmpint (int_value, ==, ARV_FAKE_CAMERA_BINNING_VERTICAL_DEFAULT);
-	int_value = arv_device_get_integer_feature_value (device, "PixelFormat");
+	int_value = arv_device_get_integer_feature_value (device, "PixelFormat", NULL);
 	g_assert_cmpint (int_value, ==, ARV_FAKE_CAMERA_PIXEL_FORMAT_DEFAULT);
 
-	dbl_value = arv_device_get_float_feature_value (device, "AcquisitionFrameRate");
+	dbl_value = arv_device_get_float_feature_value (device, "AcquisitionFrameRate", NULL);
 	g_assert_cmpfloat (dbl_value, ==, ARV_FAKE_CAMERA_ACQUISITION_FRAME_RATE_DEFAULT);
-	dbl_value = arv_device_get_float_feature_value (device,  "ExposureTimeAbs");
+	dbl_value = arv_device_get_float_feature_value (device,  "ExposureTimeAbs", NULL);
 	g_assert_cmpfloat (dbl_value, ==, ARV_FAKE_CAMERA_EXPOSURE_TIME_US_DEFAULT);
 
-	int_value = arv_device_get_integer_feature_value (device, "GainRaw");
+	int_value = arv_device_get_integer_feature_value (device, "GainRaw", NULL);
 	g_assert_cmpint (int_value, ==, 0);
-	int_value = arv_device_get_integer_feature_value (device, "GainAuto");
+	int_value = arv_device_get_integer_feature_value (device, "GainAuto", NULL);
 	g_assert_cmpint (int_value, ==, 1);
 
-	int_value = arv_device_get_integer_feature_value (device, "PayloadSize");
+	int_value = arv_device_get_integer_feature_value (device, "PayloadSize", NULL);
 	g_assert_cmpint (int_value, ==, 1024 * 1024);
 
-	arv_device_set_boolean_feature_value (device, "TestBoolean", FALSE);
-	boolean_value = arv_device_get_boolean_feature_value (device, "TestBoolean");
+	arv_device_set_boolean_feature_value (device, "TestBoolean", FALSE, NULL);
+	boolean_value = arv_device_get_boolean_feature_value (device, "TestBoolean", NULL);
 	g_assert_cmpint (boolean_value, ==, FALSE);
-	int_value = arv_device_get_integer_feature_value (device, "TestRegister");
+	int_value = arv_device_get_integer_feature_value (device, "TestRegister", NULL);
 	g_assert_cmpint (int_value, ==, 123);
 
-	arv_device_set_boolean_feature_value (device, "TestBoolean", TRUE);
-	boolean_value = arv_device_get_boolean_feature_value (device, "TestBoolean");
+	arv_device_set_boolean_feature_value (device, "TestBoolean", TRUE, NULL);
+	boolean_value = arv_device_get_boolean_feature_value (device, "TestBoolean", NULL);
 	g_assert_cmpint (boolean_value, ==, TRUE);
-	int_value = arv_device_get_integer_feature_value (device, "TestRegister");
+	int_value = arv_device_get_integer_feature_value (device, "TestRegister", NULL);
 	g_assert_cmpint (int_value, ==, 321);
 
-	arv_device_get_integer_feature_bounds (device, "Width", &minimum, &maximum);
+	arv_device_get_integer_feature_bounds (device, "Width", &minimum, &maximum, NULL);
 	g_assert_cmpint (minimum, ==, 1);
 	g_assert_cmpint (maximum, ==, 2048);
 
-	arv_device_get_float_feature_bounds (device, "ExposureTimeAbs", &float_minimum, &float_maximum);
+	arv_device_get_float_feature_bounds (device, "ExposureTimeAbs", &float_minimum, &float_maximum, NULL);
 	g_assert_cmpfloat (float_minimum, ==, 10.0);
 	g_assert_cmpfloat (float_maximum, ==, 10000000.0);
 
-	arv_device_set_float_feature_value (device,  "ExposureTimeAbs", 20.0);
-	dbl_value = arv_device_get_float_feature_value (device,  "ExposureTimeAbs");
+	arv_device_set_float_feature_value (device,  "ExposureTimeAbs", 20.0, NULL);
+	dbl_value = arv_device_get_float_feature_value (device,  "ExposureTimeAbs", NULL);
 	g_assert_cmpfloat (dbl_value, ==, 20.0);
 
-	values = arv_device_get_available_enumeration_feature_values (device, "GainAuto", &n_values);
+	values = arv_device_get_available_enumeration_feature_values (device, "GainAuto", &n_values, NULL);
 	g_assert (values != NULL);
 	g_assert_cmpint (n_values, ==, 3);
 	g_free (values);
 
-	string_values = arv_device_get_available_enumeration_feature_values_as_strings (device, "GainAuto", &n_values);
+	string_values = arv_device_get_available_enumeration_feature_values_as_strings (device, "GainAuto", &n_values, NULL);
 	g_assert (string_values != NULL);
 	g_assert_cmpint (n_values, ==, 3);
 	g_free (string_values);
 
-	arv_device_set_string_feature_value (device, "TestStringReg", "String");
-	string_value = arv_device_get_string_feature_value (device, "TestStringReg");
+	arv_device_set_string_feature_value (device, "TestStringReg", "String", NULL);
+	string_value = arv_device_get_string_feature_value (device, "TestStringReg", NULL);
 	g_assert_cmpstr (string_value, ==, "String");
 
-	status = arv_device_get_status (device);
-	g_assert_cmpint (status, ==, ARV_DEVICE_STATUS_SUCCESS);
-
 	g_object_unref (device);
 }
 
@@ -234,27 +226,24 @@ static void
 fake_device_error_test (void)
 {
 	ArvDevice *device;
-	ArvDeviceStatus status;
+	GError *error = NULL;
 	int int_value;
-	double dbl_value;
 	double boolean_value;
-	gint64 minimum, maximum;
-	gint64 *values;
-	const char **string_values;
-	int n_values;
-	double float_minimum, float_maximum;
 
 	device = arv_fake_device_new ("TEST0");
 	g_assert (ARV_IS_FAKE_DEVICE (device));
 
-	int_value = arv_device_get_integer_feature_value (device, "Unknown");
+	int_value = arv_device_get_integer_feature_value (device, "Unknown", &error);
 	g_assert_cmpint (int_value, ==, 0);
+	g_assert (error != NULL);
 
-	boolean_value = arv_device_get_boolean_feature_value (device, "Unknown");
+	g_clear_error (&error);
+
+	boolean_value = arv_device_get_boolean_feature_value (device, "Unknown", &error);
 	g_assert_cmpint (boolean_value, ==, 0);
+	g_assert (error != NULL);
 
-	status = arv_device_get_status (device);
-	g_assert_cmpint (status, ==, ARV_DEVICE_STATUS_SUCCESS);
+	g_clear_error (&error);
 
 	g_object_unref (device);
 }
@@ -324,6 +313,128 @@ fake_stream_test (void)
 	g_clear_object (&camera);
 }
 
+static void
+camera_api_test (void)
+{
+	ArvCamera *camera;
+	ArvPixelFormat pixel_format;
+	ArvStatus status;
+	GError *error = NULL;
+	int x, y, w, h;
+	const char *string;
+	void *ptr;
+	unsigned int n;
+	gboolean b;
+	double d;
+
+	camera = arv_camera_new ("Fake_1");
+	g_assert (ARV_IS_CAMERA (camera));
+
+	string = arv_camera_get_vendor_name (camera);
+	g_assert (string != NULL);
+
+	string = arv_camera_get_model_name (camera);
+	g_assert (string != NULL);
+
+	string = arv_camera_get_device_id (camera);
+	g_assert (string != NULL);
+
+	arv_camera_get_region (camera, &x, &y, &w, &h);
+	g_assert_cmpint (x, ==, 0);
+	g_assert_cmpint (y, ==, 0);
+	g_assert_cmpint (w, ==, ARV_FAKE_CAMERA_WIDTH_DEFAULT);
+	g_assert_cmpint (h, ==, ARV_FAKE_CAMERA_HEIGHT_DEFAULT);
+
+	arv_camera_get_sensor_size (camera, &w, &h);
+	g_assert_cmpint (w, ==, ARV_FAKE_CAMERA_SENSOR_WIDTH);
+	g_assert_cmpint (h, ==, ARV_FAKE_CAMERA_SENSOR_HEIGHT);
+
+	arv_camera_set_region (camera, 10, 20, 30, 40);
+	arv_camera_get_region (camera, &x, &y, &w, &h);
+	g_assert_cmpint (x, ==, 10);
+	g_assert_cmpint (y, ==, 20);
+	g_assert_cmpint (w, ==, 30);
+	g_assert_cmpint (h, ==, 40);
+
+	arv_camera_get_binning (camera, &x, &y);
+	g_assert_cmpint (x, ==, ARV_FAKE_CAMERA_BINNING_HORIZONTAL_DEFAULT);
+	g_assert_cmpint (y, ==, ARV_FAKE_CAMERA_BINNING_VERTICAL_DEFAULT);
+
+	arv_camera_set_binning (camera, 2, 4);
+	arv_camera_get_binning (camera, &x, &y);
+	g_assert_cmpint (x, ==, 2);
+	g_assert_cmpint (y, ==, 4);
+
+	b = arv_camera_is_binning_available (camera);
+	g_assert (b);
+
+	pixel_format = arv_camera_get_pixel_format (camera);
+	g_assert_cmpint (pixel_format, ==, ARV_PIXEL_FORMAT_MONO_8);
+
+	arv_camera_set_pixel_format (camera, ARV_PIXEL_FORMAT_RGB_8_PACKED);
+	pixel_format = arv_camera_get_pixel_format (camera);
+	g_assert_cmpint (pixel_format, ==, ARV_PIXEL_FORMAT_RGB_8_PACKED);
+
+	string = arv_camera_get_pixel_format_as_string (camera);
+	g_assert_cmpstr (string, ==, "RGB8");
+
+	arv_camera_set_pixel_format_from_string (camera, "Mono8");
+	pixel_format = arv_camera_get_pixel_format (camera);
+	g_assert_cmpint (pixel_format, ==, ARV_PIXEL_FORMAT_MONO_8);
+
+	ptr = arv_camera_get_available_pixel_formats (camera, &n);
+	g_assert (ptr != NULL);
+	g_assert_cmpint (n, ==, 2);
+	g_clear_pointer (&ptr, g_free);
+
+	ptr = arv_camera_get_available_pixel_formats_as_strings (camera, &n);
+	g_assert (ptr != NULL);
+	g_assert_cmpint (n, ==, 2);
+	g_clear_pointer (&ptr, g_free);
+
+	ptr = arv_camera_get_available_pixel_formats_as_display_names (camera, &n);
+	g_assert (ptr != NULL);
+	g_assert_cmpint (n, ==, 2);
+	g_clear_pointer (&ptr, g_free);
+
+	b = arv_camera_is_frame_rate_available (camera);
+	g_assert (b);
+
+	d = arv_camera_get_frame_rate (camera);
+	g_assert_cmpfloat (d, ==, ARV_FAKE_CAMERA_ACQUISITION_FRAME_RATE_DEFAULT);
+
+	arv_camera_set_frame_rate (camera, 10.0);
+	d = arv_camera_get_frame_rate (camera);
+	g_assert_cmpfloat (d, ==, 10.0);
+
+	b = arv_camera_is_exposure_auto_available (camera);
+	g_assert (!b);
+
+	b = arv_camera_is_exposure_time_available (camera);
+	g_assert (b);
+
+	arv_camera_set_gain (camera, 1.0);
+	d = arv_camera_get_gain (camera);
+	g_assert_cmpfloat (d, ==, 1.0);
+
+	status = arv_camera_get_status (camera, &error);
+	g_assert_cmpint (status, ==, ARV_STATUS_SUCCESS);
+	g_assert (error == NULL);
+
+	arv_camera_set_integer (camera, "Unknown", 0);
+	status = arv_camera_get_status (camera, &error);
+	g_assert_cmpint (status, !=, ARV_STATUS_SUCCESS);
+	g_assert (error != NULL);
+	g_clear_error (&error);
+
+	/* Status is reset after read */
+	status = arv_camera_get_status (camera, &error);
+	g_assert_cmpint (status, ==, ARV_STATUS_SUCCESS);
+	g_assert (error == NULL);
+
+	g_object_unref (camera);
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -331,20 +442,18 @@ main (int argc, char *argv[])
 
 	g_test_init (&argc, &argv, NULL);
 
-	arv_g_type_init ();
+	arv_set_fake_camera_genicam_filename (GENICAM_FILENAME);
 
 	arv_enable_interface ("Fake");
 
 	arv_update_device_list ();
 
-	arv_set_fake_camera_genicam_filename (GENICAM_FILENAME);
-
-	g_test_add_func ("/fake/load-fake-camera-genicam", load_fake_camera_genicam_test);
 	g_test_add_func ("/fake/trigger-registers", trigger_registers_test);
 	g_test_add_func ("/fake/registers", registers_test);
 	g_test_add_func ("/fake/fake-device", fake_device_test);
 	g_test_add_func ("/fake/fake-device-error", fake_device_error_test);
 	g_test_add_func ("/fake/fake-stream", fake_stream_test);
+	g_test_add_func ("/fake/camera-api", camera_api_test);
 
 	result = g_test_run();
 
