@@ -7,10 +7,10 @@
 
 typedef struct {
 	const char *name;
-	GType value_type;
+	GType type;
 } NodeTypes;
 
-NodeTypes node_value_types[] = {
+NodeTypes node_types[] = {
 	{"RWFloat",			G_TYPE_DOUBLE},
 	{"P_RWFloat_Min",		G_TYPE_DOUBLE},
 	{"P_RWFloat_Max",		G_TYPE_DOUBLE},
@@ -45,9 +45,22 @@ node_value_type_test (void)
 	genicam = arv_device_get_genicam (device);
 	g_assert (ARV_IS_GC (genicam));
 
-	for (i = 0; i < G_N_ELEMENTS (node_value_types); i++) {
-		node = arv_gc_get_node (genicam, node_value_types[i].name);
-		g_assert (arv_gc_feature_node_get_value_type (ARV_GC_FEATURE_NODE (node)) == node_value_types[i].value_type);
+	for (i = 0; i < G_N_ELEMENTS (node_types); i++) {
+		node = arv_gc_get_node (genicam, node_types[i].name);
+		switch (node_types[i].type) {
+			case G_TYPE_STRING:
+				g_assert (ARV_IS_GC_STRING (node));
+				break;
+			case G_TYPE_DOUBLE:
+				g_assert (ARV_IS_GC_FLOAT (node));
+				break;
+			case G_TYPE_INT64:
+				g_assert (ARV_IS_GC_INTEGER (node));
+				break;
+			case G_TYPE_BOOLEAN:
+				g_assert (ARV_IS_GC_BOOLEAN (node));
+				break;
+		}
 	}
 
 	g_object_unref (device);
@@ -246,7 +259,6 @@ boolean_test (void)
 	ArvGcNode *node_b;
 	gboolean v_boolean;
 	const char *v_string;
-	gint64 v_int64;
 
 	device = arv_fake_device_new ("TEST0");
 	g_assert (ARV_IS_FAKE_DEVICE (device));
@@ -256,14 +268,10 @@ boolean_test (void)
 
 	node = arv_gc_get_node (genicam, "RWBoolean");
 	g_assert (ARV_IS_GC_BOOLEAN (node));
-	g_assert (ARV_IS_GC_INTEGER (node));
 
 	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
 	g_assert_cmpint (v_boolean, ==, TRUE);
 
-	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node), NULL);
-	g_assert_cmpint (v_int64, ==, 1);
-
 	v_string = arv_gc_feature_node_get_value_as_string (ARV_GC_FEATURE_NODE (node), NULL);
 	g_assert_cmpstr (v_string, ==, "true");
 
@@ -271,9 +279,6 @@ boolean_test (void)
 	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
 	g_assert_cmpint (v_boolean, ==, FALSE);
 
-	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node), NULL);
-	g_assert_cmpint (v_int64, ==, 0);
-
 	v_string = arv_gc_feature_node_get_value_as_string (ARV_GC_FEATURE_NODE (node), NULL);
 	g_assert_cmpstr (v_string, ==, "false");
 
@@ -511,13 +516,19 @@ converter_test (void)
 static void
 register_test (void)
 {
+	GError *error = NULL;
 	ArvDevice *device;
 	ArvGc *genicam;
 	ArvGcNode *node_a;
 	ArvGcNode *node_b;
 	ArvGcNode *node_c;
 	ArvGcNode *node_sc;
+	ArvGcNode *node_uc;
+	ArvGcNode *node_f;
+	ArvGcNode *node_str;
+	const char *string;
 	gint64 value;
+	double value_f;
 
 	device = arv_fake_device_new ("TEST0");
 	g_assert (ARV_IS_FAKE_DEVICE (device));
@@ -525,8 +536,16 @@ register_test (void)
 	genicam = arv_device_get_genicam (device);
 	g_assert (ARV_IS_GC (genicam));
 
+	/* 64 bit IntReg */
+
 	node_a = arv_gc_get_node (genicam, "IntRegisterA");
 	g_assert (ARV_IS_GC_REGISTER (node_a));
+	value = arv_gc_integer_get_min (ARV_GC_INTEGER (node_a), NULL);
+	g_assert_cmpint (value, ==, 0);
+	value = arv_gc_integer_get_max (ARV_GC_INTEGER (node_a), NULL);
+	g_assert_cmpint (value, ==, G_MAXINT64);
+	string = arv_gc_integer_get_unit (ARV_GC_INTEGER (node_a), NULL);
+	g_assert_cmpstr (string, ==, "Pa");
 
 	value = arv_gc_register_get_address (ARV_GC_REGISTER (node_a), NULL);
 	g_assert_cmpint (value, ==, 0x1050);
@@ -540,24 +559,163 @@ register_test (void)
 	node_c = arv_gc_get_node (genicam, "IntRegisterC");
 	g_assert (ARV_IS_GC_REGISTER (node_c));
 
-	arv_gc_integer_set_value (ARV_GC_INTEGER (node_c), 0, NULL);
+	/* 32 bit IntReg */
 
-	node_sc = arv_gc_get_node (genicam, "IntSignedRegisterC");
+	arv_gc_integer_set_value (ARV_GC_INTEGER (node_c), 0x1234567887654321, NULL);
+
+	node_sc = arv_gc_get_node (genicam, "IntSigned32BitRegisterC");
 	g_assert (ARV_IS_GC_REGISTER (node_sc));
+	value = arv_gc_integer_get_min (ARV_GC_INTEGER (node_sc), NULL);
+	g_assert_cmpint (value, ==, G_MININT32);
+	value = arv_gc_integer_get_max (ARV_GC_INTEGER (node_sc), NULL);
+	g_assert_cmpint (value, ==, G_MAXINT32);
+	value = arv_gc_integer_get_inc (ARV_GC_INTEGER (node_sc), NULL);
+	g_assert_cmpint (value, ==, 1);
+
+	node_uc = arv_gc_get_node (genicam, "IntUnsigned32BitRegisterC");
+	g_assert (ARV_IS_GC_REGISTER (node_uc));
+	value = arv_gc_integer_get_min (ARV_GC_INTEGER (node_uc), NULL);
+	g_assert_cmpint (value, ==, 0);
+	value = arv_gc_integer_get_max (ARV_GC_INTEGER (node_uc), NULL);
+	g_assert_cmpint (value, ==, G_MAXUINT32);
+	value = arv_gc_integer_get_inc (ARV_GC_INTEGER (node_uc), NULL);
+	g_assert_cmpint (value, ==, 1);
 
 	arv_gc_integer_set_value (ARV_GC_INTEGER (node_sc), -1, NULL);
 
 	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_sc), NULL);
 	g_assert_cmpint (value, ==, -1);
 
+	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_uc), NULL);
+	g_assert_cmpint (value, ==, 0xffffffff);
+
 	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_c), NULL);
-	g_assert_cmpint (value, ==, 0x00000000ffffffff);
+	g_assert_cmpint (value, ==, 0x12345678ffffffff);
 
 	arv_gc_integer_set_value (ARV_GC_INTEGER (node_sc), 0x7fffffff, NULL);
 
 	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_sc), NULL);
 	g_assert_cmpint (value, ==, 0x7fffffff);
 
+	/* 16 bit IntReg */
+
+	node_sc = arv_gc_get_node (genicam, "IntSigned16BitRegisterC");
+	g_assert (ARV_IS_GC_REGISTER (node_sc));
+	value = arv_gc_integer_get_min (ARV_GC_INTEGER (node_sc), NULL);
+	g_assert_cmpint (value, ==, G_MININT16);
+	value = arv_gc_integer_get_max (ARV_GC_INTEGER (node_sc), NULL);
+	g_assert_cmpint (value, ==, G_MAXINT16);
+	value = arv_gc_integer_get_inc (ARV_GC_INTEGER (node_sc), NULL);
+	g_assert_cmpint (value, ==, 1);
+
+	node_uc = arv_gc_get_node (genicam, "IntUnsigned16BitRegisterC");
+	g_assert (ARV_IS_GC_REGISTER (node_uc));
+	value = arv_gc_integer_get_min (ARV_GC_INTEGER (node_uc), NULL);
+	g_assert_cmpint (value, ==, 0);
+	value = arv_gc_integer_get_max (ARV_GC_INTEGER (node_uc), NULL);
+	g_assert_cmpint (value, ==, G_MAXUINT16);
+	value = arv_gc_integer_get_inc (ARV_GC_INTEGER (node_uc), NULL);
+	g_assert_cmpint (value, ==, 1);
+
+	arv_gc_integer_set_value (ARV_GC_INTEGER (node_sc), -1, NULL);
+
+	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_sc), NULL);
+	g_assert_cmpint (value, ==, -1);
+
+	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_uc), NULL);
+	g_assert_cmpint (value, ==, 0xffff);
+
+	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_c), NULL);
+	g_assert_cmpint (value, ==, 0xffff56787fffffff);
+
+	/* MaskedIntReg */
+
+	node_sc = arv_gc_get_node (genicam, "MaskedIntSignedRegisterC");
+	g_assert (ARV_IS_GC_REGISTER (node_sc));
+	value = arv_gc_integer_get_min (ARV_GC_INTEGER (node_sc), NULL);
+	g_assert_cmpint (value, ==, -8);
+	value = arv_gc_integer_get_max (ARV_GC_INTEGER (node_sc), NULL);
+	g_assert_cmpint (value, ==, 7);
+	value = arv_gc_integer_get_inc (ARV_GC_INTEGER (node_sc), NULL);
+	g_assert_cmpint (value, ==, 1);
+	string = arv_gc_integer_get_unit (ARV_GC_INTEGER (node_sc), NULL);
+	g_assert_cmpstr (string, ==, "V");
+
+	node_uc = arv_gc_get_node (genicam, "MaskedIntUnsignedRegisterC");
+	g_assert (ARV_IS_GC_REGISTER (node_uc));
+	value = arv_gc_integer_get_min (ARV_GC_INTEGER (node_uc), NULL);
+	g_assert_cmpint (value, ==, 0);
+	value = arv_gc_integer_get_max (ARV_GC_INTEGER (node_uc), NULL);
+	g_assert_cmpint (value, ==, 15);
+	value = arv_gc_integer_get_inc (ARV_GC_INTEGER (node_uc), NULL);
+	g_assert_cmpint (value, ==, 1);
+	string = arv_gc_integer_get_unit (ARV_GC_INTEGER (node_uc), NULL);
+	g_assert_cmpstr (string, ==, "A");
+
+	/* 4 byte FLoatReg */
+
+	arv_gc_integer_set_value (ARV_GC_INTEGER (node_c), 0x1234567887654321, NULL);
+
+	node_f = arv_gc_get_node (genicam, "FloatReg4C");
+	g_assert (ARV_IS_GC_REGISTER (node_f));
+	value_f = arv_gc_float_get_min (ARV_GC_FLOAT (node_f), NULL);
+	g_assert_cmpfloat (value_f, ==, -G_MAXFLOAT);
+	value_f = arv_gc_float_get_max (ARV_GC_FLOAT (node_f), NULL);
+	g_assert_cmpfloat (value_f, ==, G_MAXFLOAT);
+	string = arv_gc_float_get_unit (ARV_GC_FLOAT (node_f), NULL);
+	g_assert_cmpstr (string, ==, "mA");
+
+	arv_gc_float_set_value (ARV_GC_FLOAT (node_f), 2.0, NULL);
+	value_f = arv_gc_float_get_value (ARV_GC_FLOAT (node_f), NULL);
+	g_assert_cmpfloat (value_f, ==, 2.0);
+	arv_gc_float_set_value (ARV_GC_FLOAT (node_f), -1.0, NULL);
+	value_f = arv_gc_float_get_value (ARV_GC_FLOAT (node_f), NULL);
+	g_assert_cmpfloat (value_f, ==, -1.0);
+
+	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_c), NULL);
+	g_assert_cmpint (value, ==, 0x000080bf87654321);
+
+	/* 8 byte FLoatReg */
+
+	node_f = arv_gc_get_node (genicam, "FloatReg8C");
+	g_assert (ARV_IS_GC_REGISTER (node_f));
+	value_f = arv_gc_float_get_min (ARV_GC_FLOAT (node_f), NULL);
+	g_assert_cmpfloat (value_f, ==, -G_MAXDOUBLE);
+	value_f = arv_gc_float_get_max (ARV_GC_FLOAT (node_f), NULL);
+	g_assert_cmpfloat (value_f, ==, G_MAXDOUBLE);
+	string = arv_gc_float_get_unit (ARV_GC_FLOAT (node_f), NULL);
+	g_assert_cmpstr (string, ==, "mV");
+
+	arv_gc_float_set_value (ARV_GC_FLOAT (node_f), 1.2, NULL);
+	value_f = arv_gc_float_get_value (ARV_GC_FLOAT (node_f), NULL);
+	g_assert_cmpfloat (value_f, ==, 1.2);
+	arv_gc_float_set_value (ARV_GC_FLOAT (node_f), -1.0, NULL);
+	value_f = arv_gc_float_get_value (ARV_GC_FLOAT (node_f), NULL);
+	g_assert_cmpfloat (value_f, ==, -1.0);
+
+	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_c), NULL);
+	g_assert_cmpint (value, ==, 0x000000000000f0bf);
+
+	/* StringReg */
+
+	arv_gc_integer_set_value (ARV_GC_INTEGER (node_c), 0x1234567887654321, NULL);
+
+	node_str = arv_gc_get_node (genicam, "StringReg");
+	g_assert (ARV_IS_GC_REGISTER (node_str));
+	value = arv_gc_string_get_max_length (ARV_GC_STRING (node_str), NULL);
+	g_assert_cmpint (value, ==, 4);
+
+	arv_gc_string_set_value (ARV_GC_STRING (node_str), "Toto", NULL);
+	string = arv_gc_string_get_value (ARV_GC_STRING (node_str), NULL);
+	g_assert_cmpstr (string, ==, "Toto");
+
+	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node_c), NULL);
+	g_assert_cmpint (value, ==, 0x1234546f746f4321);
+
+	arv_gc_string_set_value (ARV_GC_STRING (node_str), "TotoTata", &error);
+	g_assert (error != NULL);
+	g_clear_error (&error);
+
 	g_object_unref (device);
 }
 
@@ -626,11 +784,12 @@ create_buffer_with_chunk_data (void)
 	char *data;
 	size_t size;
 	guint32 *int_value;
+	guint8 *boolean_value;
 	guint offset;
 	double float_value;
 	int i;
 
-	size = 64 + 8 + 64 + 8 + 4 * sizeof (ArvChunkInfos);
+	size = 64 + 8 + 64 + 8 + 1 + 5 * sizeof (ArvChunkInfos);
 
 	buffer = arv_buffer_new (size, NULL);
 	buffer->priv->payload_type = ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA;
@@ -665,10 +824,18 @@ create_buffer_with_chunk_data (void)
 
 	offset -= 8 + sizeof (ArvChunkInfos);
 	chunk_infos = (ArvChunkInfos *) &data[offset];
+	chunk_infos->id = GUINT32_TO_BE (0x12345680);
+	chunk_infos->size = GUINT32_TO_BE (1);
+
+	boolean_value = (guint8 *) &data[offset - 1];
+	*boolean_value = 0x1;
+
+	offset -= 1 + sizeof (ArvChunkInfos);
+	chunk_infos = (ArvChunkInfos *) &data[offset];
 	chunk_infos->id = GUINT32_TO_BE (0x44444444);
 	chunk_infos->size = GUINT32_TO_BE (64);
 
-	g_assert (offset == 64);
+	g_assert_cmpint (offset, ==, 64);
 
 #if 0
 	{
@@ -690,8 +857,10 @@ chunk_data_test (void)
 	ArvChunkParser *parser;
 	ArvBuffer *buffer;
 	ArvGc *genicam;
+	GError *error = NULL;
 	guint32 int_value;
 	double float_value;
+	gboolean boolean_value;
 	const char *chunk_data;
 	const char *data;
 	const char *string_value;
@@ -715,34 +884,49 @@ chunk_data_test (void)
 	chunk_data = arv_buffer_get_chunk_data (buffer, 0x12345678, &chunk_data_size);
 	g_assert (chunk_data != NULL);
 	g_assert_cmpint (chunk_data_size, ==, 8);
-	g_assert_cmpint (chunk_data - data, ==, 64 + 64 + 8 + 3 * sizeof (ArvChunkInfos));
+	g_assert_cmpint (chunk_data - data, ==, 1 + 64 + 64 + 8 + 4 * sizeof (ArvChunkInfos));
 
 	chunk_data = arv_buffer_get_chunk_data (buffer, 0x12345679, &chunk_data_size);
 	g_assert (chunk_data != NULL);
 	g_assert_cmpint (chunk_data_size, ==, 8);
-	g_assert_cmpint (chunk_data - data, ==, 64 + sizeof (ArvChunkInfos));
+	g_assert_cmpint (chunk_data - data, ==, 1 + 64 + 2 * sizeof (ArvChunkInfos));
 
 	chunk_data = arv_buffer_get_chunk_data (buffer, 0x87654321, &chunk_data_size);
 	g_assert (chunk_data != NULL);
 	g_assert_cmpint (chunk_data_size, ==, 64);
-	g_assert_cmpint (chunk_data - data, ==, 64 + 8 + 2 * sizeof (ArvChunkInfos));
+	g_assert_cmpint (chunk_data - data, ==, 1 + 64 + 8 + 3 * sizeof (ArvChunkInfos));
 
 	chunk_data = arv_buffer_get_chunk_data (buffer, 0x01020304, &chunk_data_size);
 	g_assert (chunk_data == NULL);
 	g_assert_cmpint (chunk_data_size, ==, 0);
 
-	int_value = arv_chunk_parser_get_integer_value (parser, buffer, "ChunkInt");
+	int_value = arv_chunk_parser_get_integer_value (parser, buffer, "ChunkInt", &error);
 	g_assert_cmpint (int_value, ==, 0x11223344);
+	g_assert (error == NULL);
 
-	float_value = arv_chunk_parser_get_float_value (parser, buffer, "ChunkFloat");
+	float_value = arv_chunk_parser_get_float_value (parser, buffer, "ChunkFloat", &error);
 	g_assert_cmpfloat (float_value, ==, 1.1);
+	g_assert (error == NULL);
 
-	string_value = arv_chunk_parser_get_string_value (parser, buffer, "ChunkString");
+	string_value = arv_chunk_parser_get_string_value (parser, buffer, "ChunkString", &error);
 	g_assert_cmpstr (string_value, ==, "Hello");
+	g_assert (error == NULL);
 
-	arv_chunk_parser_get_integer_value (parser, buffer, "Dummy");
-	arv_chunk_parser_get_float_value (parser, buffer, "Dummy");
-	arv_chunk_parser_get_string_value (parser, buffer, "Dummy");
+	boolean_value = arv_chunk_parser_get_boolean_value (parser, buffer, "ChunkBoolean", &error);
+	g_assert (boolean_value);
+	g_assert (error == NULL);
+
+	arv_chunk_parser_get_integer_value (parser, buffer, "Dummy", &error);
+	g_assert (error != NULL);
+	g_clear_error (&error);
+
+	arv_chunk_parser_get_float_value (parser, buffer, "Dummy", &error);
+	g_assert (error != NULL);
+	g_clear_error (&error);
+
+	arv_chunk_parser_get_string_value (parser, buffer, "Dummy", &error);
+	g_assert (error != NULL);
+	g_clear_error (&error);
 
 	g_object_unref (buffer);
 	g_object_unref (parser);
